Class: Prism::BreakNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents the use of the ‘break` keyword.

break foo
^^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(arguments, keyword_loc, location) ⇒ BreakNode

def initialize: (arguments: ArgumentsNode?, keyword_loc: Location, location: Location) -> void



1874
1875
1876
1877
1878
# File 'lib/prism/node.rb', line 1874

def initialize(arguments, keyword_loc, location)
  @arguments = arguments
  @keyword_loc = keyword_loc
  @location = location
end

Instance Attribute Details

#argumentsObject (readonly)

attr_reader arguments: ArgumentsNode?



1868
1869
1870
# File 'lib/prism/node.rb', line 1868

def arguments
  @arguments
end

#keyword_locObject (readonly)

attr_reader keyword_loc: Location



1871
1872
1873
# File 'lib/prism/node.rb', line 1871

def keyword_loc
  @keyword_loc
end

Class Method Details

.typeObject

Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.

def self.type: () -> Symbol



1961
1962
1963
# File 'lib/prism/node.rb', line 1961

def self.type
  :break_node
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



1881
1882
1883
# File 'lib/prism/node.rb', line 1881

def accept(visitor)
  visitor.visit_break_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



1886
1887
1888
# File 'lib/prism/node.rb', line 1886

def child_nodes
  [arguments]
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



1898
1899
1900
# File 'lib/prism/node.rb', line 1898

def comment_targets
  [*arguments, keyword_loc]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



1891
1892
1893
1894
1895
# File 'lib/prism/node.rb', line 1891

def compact_child_nodes
  compact = []
  compact << arguments if arguments
  compact
end

#copy(**params) ⇒ Object

def copy: (**params) -> BreakNode



1903
1904
1905
1906
1907
1908
1909
# File 'lib/prism/node.rb', line 1903

def copy(**params)
  BreakNode.new(
    params.fetch(:arguments) { arguments },
    params.fetch(:keyword_loc) { keyword_loc },
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array | String | Token | Array | Location]



1915
1916
1917
# File 'lib/prism/node.rb', line 1915

def deconstruct_keys(keys)
  { arguments: arguments, keyword_loc: keyword_loc, location: location }
end

#inspect(inspector = NodeInspector.new) ⇒ Object

def inspect(inspector: NodeInspector) -> String



1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
# File 'lib/prism/node.rb', line 1925

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  if (arguments = self.arguments).nil?
    inspector << "├── arguments: ∅\n"
  else
    inspector << "├── arguments:\n"
    inspector << arguments.inspect(inspector.child_inspector("")).delete_prefix(inspector.prefix)
  end
  inspector << "└── keyword_loc: #{inspector.location(keyword_loc)}\n"
  inspector.to_str
end

#keywordObject

def keyword: () -> String



1920
1921
1922
# File 'lib/prism/node.rb', line 1920

def keyword
  keyword_loc.slice
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



1951
1952
1953
# File 'lib/prism/node.rb', line 1951

def type
  :break_node
end