Class: Prism::ConstantPathOperatorWriteNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::ConstantPathOperatorWriteNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents assigning to a constant path using an operator that isn’t ‘=`.
Parent::Child += value
^^^^^^^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#operator ⇒ Object
readonly
attr_reader operator: Symbol.
-
#operator_loc ⇒ Object
readonly
attr_reader operator_loc: Location.
-
#target ⇒ Object
readonly
attr_reader target: ConstantPathNode.
-
#value ⇒ Object
readonly
attr_reader value: Node.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> ConstantPathOperatorWriteNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(target, operator_loc, value, operator, location) ⇒ ConstantPathOperatorWriteNode
constructor
def initialize: (target: ConstantPathNode, operator_loc: Location, value: Node, operator: Symbol, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(target, operator_loc, value, operator, location) ⇒ ConstantPathOperatorWriteNode
def initialize: (target: ConstantPathNode, operator_loc: Location, value: Node, operator: Symbol, location: Location) -> void
4351 4352 4353 4354 4355 4356 4357 |
# File 'lib/prism/node.rb', line 4351 def initialize(target, operator_loc, value, operator, location) @target = target @operator_loc = operator_loc @value = value @operator = operator @location = location end |
Instance Attribute Details
#operator ⇒ Object (readonly)
attr_reader operator: Symbol
4348 4349 4350 |
# File 'lib/prism/node.rb', line 4348 def operator @operator end |
#operator_loc ⇒ Object (readonly)
attr_reader operator_loc: Location
4342 4343 4344 |
# File 'lib/prism/node.rb', line 4342 def operator_loc @operator_loc end |
#target ⇒ Object (readonly)
attr_reader target: ConstantPathNode
4339 4340 4341 |
# File 'lib/prism/node.rb', line 4339 def target @target end |
#value ⇒ Object (readonly)
attr_reader value: Node
4345 4346 4347 |
# File 'lib/prism/node.rb', line 4345 def value @value end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
4434 4435 4436 |
# File 'lib/prism/node.rb', line 4434 def self.type :constant_path_operator_write_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
4360 4361 4362 |
# File 'lib/prism/node.rb', line 4360 def accept(visitor) visitor.visit_constant_path_operator_write_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
4365 4366 4367 |
# File 'lib/prism/node.rb', line 4365 def child_nodes [target, value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
4375 4376 4377 |
# File 'lib/prism/node.rb', line 4375 def comment_targets [target, operator_loc, value] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
4370 4371 4372 |
# File 'lib/prism/node.rb', line 4370 def compact_child_nodes [target, value] end |
#copy(**params) ⇒ Object
def copy: (**params) -> ConstantPathOperatorWriteNode
4380 4381 4382 4383 4384 4385 4386 4387 4388 |
# File 'lib/prism/node.rb', line 4380 def copy(**params) ConstantPathOperatorWriteNode.new( params.fetch(:target) { target }, params.fetch(:operator_loc) { operator_loc }, params.fetch(:value) { value }, params.fetch(:operator) { operator }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
4394 4395 4396 |
# File 'lib/prism/node.rb', line 4394 def deconstruct_keys(keys) { target: target, operator_loc: operator_loc, value: value, operator: operator, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 |
# File 'lib/prism/node.rb', line 4399 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── target:\n" inspector << inspector.child_node(target, "│ ") inspector << "├── operator_loc: #{inspector.location(operator_loc)}\n" inspector << "├── value:\n" inspector << inspector.child_node(value, "│ ") inspector << "└── operator: #{operator.inspect}\n" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
4424 4425 4426 |
# File 'lib/prism/node.rb', line 4424 def type :constant_path_operator_write_node end |