Class: Prism::ConstantPathTargetNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
lib/prism/node_ext.rb,
ext/prism/api_node.c

Overview

Represents writing to a constant path in a context that doesn’t have an explicit value.

Foo::Foo, Bar::Bar = baz
^^^^^^^^  ^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(source, node_id, location, flags, parent, name, delimiter_loc, name_loc) ⇒ ConstantPathTargetNode

Initialize a new ConstantPathTargetNode node.



5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
# File 'lib/prism/node.rb', line 5750

def initialize(source, node_id, location, flags, parent, name, delimiter_loc, name_loc)
  @source = source
  @node_id = node_id
  @location = location
  @flags = flags
  @parent = parent
  @name = name
  @delimiter_loc = delimiter_loc
  @name_loc = name_loc
end

Instance Attribute Details

#nameObject (readonly)

attr_reader name: Symbol?



5807
5808
5809
# File 'lib/prism/node.rb', line 5807

def name
  @name
end

#parentObject (readonly)

attr_reader parent: Prism::node?



5804
5805
5806
# File 'lib/prism/node.rb', line 5804

def parent
  @parent
end

Class Method Details

.typeObject

Return a symbol representation of this node type. See Node::type.



5851
5852
5853
# File 'lib/prism/node.rb', line 5851

def self.type
  :constant_path_target_node
end

Instance Method Details

#===(other) ⇒ Object

Implements case-equality for the node. This is effectively == but without comparing the value of locations. Locations are checked only for presence.



5857
5858
5859
5860
5861
5862
5863
# File 'lib/prism/node.rb', line 5857

def ===(other)
  other.is_a?(ConstantPathTargetNode) &&
    (parent === other.parent) &&
    (name === other.name) &&
    (delimiter_loc.nil? == other.delimiter_loc.nil?) &&
    (name_loc.nil? == other.name_loc.nil?)
end

#accept(visitor) ⇒ Object

def accept: (Visitor visitor) -> void



5762
5763
5764
# File 'lib/prism/node.rb', line 5762

def accept(visitor)
  visitor.visit_constant_path_target_node(self)
end

#childObject

Previously, we had a child node on this class that contained either a constant read or a missing node. To not cause a breaking change, we continue to supply that API.



246
247
248
249
250
251
252
253
254
# File 'lib/prism/node_ext.rb', line 246

def child
  deprecated("name", "name_loc")

  if name
    ConstantReadNode.new(source, -1, name_loc, 0, name)
  else
    MissingNode.new(source, -1, location, 0)
  end
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array



5767
5768
5769
# File 'lib/prism/node.rb', line 5767

def child_nodes
  [parent]
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



5786
5787
5788
# File 'lib/prism/node.rb', line 5786

def comment_targets
  [*parent, delimiter_loc, name_loc] #: Array[Prism::node | Location]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



5779
5780
5781
5782
5783
# File 'lib/prism/node.rb', line 5779

def compact_child_nodes
  compact = [] #: Array[Prism::node]
  compact << parent if parent
  compact
end

#copy(node_id: self.node_id, location: self.location, flags: self.flags, parent: self.parent, name: self.name, delimiter_loc: self.delimiter_loc, name_loc: self.name_loc) ⇒ Object

def copy: (?node_id: Integer, ?location: Location, ?flags: Integer, ?parent: Prism::node?, ?name: Symbol?, ?delimiter_loc: Location, ?name_loc: Location) -> ConstantPathTargetNode



5791
5792
5793
# File 'lib/prism/node.rb', line 5791

def copy(node_id: self.node_id, location: self.location, flags: self.flags, parent: self.parent, name: self.name, delimiter_loc: self.delimiter_loc, name_loc: self.name_loc)
  ConstantPathTargetNode.new(source, node_id, location, flags, parent, name, delimiter_loc, name_loc)
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (Array keys) -> { node_id: Integer, location: Location, parent: Prism::node?, name: Symbol?, delimiter_loc: Location, name_loc: Location }



5799
5800
5801
# File 'lib/prism/node.rb', line 5799

def deconstruct_keys(keys)
  { node_id: node_id, location: location, parent: parent, name: name, delimiter_loc: delimiter_loc, name_loc: name_loc }
end

#delimiterObject

def delimiter: () -> String



5836
5837
5838
# File 'lib/prism/node.rb', line 5836

def delimiter
  delimiter_loc.slice
end

#delimiter_locObject

attr_reader delimiter_loc: Location



5810
5811
5812
5813
5814
# File 'lib/prism/node.rb', line 5810

def delimiter_loc
  location = @delimiter_loc
  return location if location.is_a?(Location)
  @delimiter_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#each_child_node {|parent| ... } ⇒ Object

def each_child_node: () { (Prism::node) -> void } -> void | () -> Enumerator

Yields:



5772
5773
5774
5775
5776
# File 'lib/prism/node.rb', line 5772

def each_child_node
  return to_enum(:each_child_node) unless block_given?

  yield parent if parent
end

#full_nameObject

Returns the full name of this constant path. For example: “Foo::Bar”



239
240
241
# File 'lib/prism/node_ext.rb', line 239

def full_name
  full_name_parts.join("::")
end

#full_name_partsObject

Returns the list of parts for the full name of this constant path. For example: [:Foo, :Bar]



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/prism/node_ext.rb', line 219

def full_name_parts
  parts =
    case parent
    when ConstantPathNode, ConstantReadNode
      parent.full_name_parts
    when nil
      [:""]
    else
      # e.g. self::Foo, (var)::Bar = baz
      raise ConstantPathNode::DynamicPartsInConstantPathError, "Constant target path contains dynamic parts. Cannot compute full name"
    end

  if name.nil?
    raise ConstantPathNode::MissingNodesInConstantPathError, "Constant target path contains missing nodes. Cannot compute full name"
  end

  parts.push(name)
end

#inspectObject

def inspect -> String



5841
5842
5843
# File 'lib/prism/node.rb', line 5841

def inspect
  InspectVisitor.compose(self)
end

#name_locObject

attr_reader name_loc: Location



5823
5824
5825
5826
5827
# File 'lib/prism/node.rb', line 5823

def name_loc
  location = @name_loc
  return location if location.is_a?(Location)
  @name_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#save_delimiter_loc(repository) ⇒ Object

Save the delimiter_loc location using the given saved source so that it can be retrieved later.



5818
5819
5820
# File 'lib/prism/node.rb', line 5818

def save_delimiter_loc(repository)
  repository.enter(node_id, :delimiter_loc)
end

#save_name_loc(repository) ⇒ Object

Save the name_loc location using the given saved source so that it can be retrieved later.



5831
5832
5833
# File 'lib/prism/node.rb', line 5831

def save_name_loc(repository)
  repository.enter(node_id, :name_loc)
end

#typeObject

Return a symbol representation of this node type. See ‘Node#type`.



5846
5847
5848
# File 'lib/prism/node.rb', line 5846

def type
  :constant_path_target_node
end