Class: Prism::ElseNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents an ‘else` clause in a `case`, `if`, or `unless` statement.

if a then b else c end
            ^^^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(else_keyword_loc, statements, end_keyword_loc, location) ⇒ ElseNode

def initialize: (else_keyword_loc: Location, statements: StatementsNode?, end_keyword_loc: Location?, location: Location) -> void



5575
5576
5577
5578
5579
5580
# File 'lib/prism/node.rb', line 5575

def initialize(else_keyword_loc, statements, end_keyword_loc, location)
  @else_keyword_loc = else_keyword_loc
  @statements = statements
  @end_keyword_loc = end_keyword_loc
  @location = location
end

Instance Attribute Details

#else_keyword_locObject (readonly)

attr_reader else_keyword_loc: Location



5566
5567
5568
# File 'lib/prism/node.rb', line 5566

def else_keyword_loc
  @else_keyword_loc
end

#end_keyword_locObject (readonly)

attr_reader end_keyword_loc: Location?



5572
5573
5574
# File 'lib/prism/node.rb', line 5572

def end_keyword_loc
  @end_keyword_loc
end

#statementsObject (readonly)

attr_reader statements: StatementsNode?



5569
5570
5571
# File 'lib/prism/node.rb', line 5569

def statements
  @statements
end

Class Method Details

.typeObject

Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.

def self.type: () -> Symbol



5670
5671
5672
# File 'lib/prism/node.rb', line 5670

def self.type
  :else_node
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



5583
5584
5585
# File 'lib/prism/node.rb', line 5583

def accept(visitor)
  visitor.visit_else_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



5588
5589
5590
# File 'lib/prism/node.rb', line 5588

def child_nodes
  [statements]
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



5600
5601
5602
# File 'lib/prism/node.rb', line 5600

def comment_targets
  [else_keyword_loc, *statements, *end_keyword_loc]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



5593
5594
5595
5596
5597
# File 'lib/prism/node.rb', line 5593

def compact_child_nodes
  compact = []
  compact << statements if statements
  compact
end

#copy(**params) ⇒ Object

def copy: (**params) -> ElseNode



5605
5606
5607
5608
5609
5610
5611
5612
# File 'lib/prism/node.rb', line 5605

def copy(**params)
  ElseNode.new(
    params.fetch(:else_keyword_loc) { else_keyword_loc },
    params.fetch(:statements) { statements },
    params.fetch(:end_keyword_loc) { end_keyword_loc },
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array | String | Token | Array | Location]



5618
5619
5620
# File 'lib/prism/node.rb', line 5618

def deconstruct_keys(keys)
  { else_keyword_loc: else_keyword_loc, statements: statements, end_keyword_loc: end_keyword_loc, location: location }
end

#else_keywordObject

def else_keyword: () -> String



5623
5624
5625
# File 'lib/prism/node.rb', line 5623

def else_keyword
  else_keyword_loc.slice
end

#end_keywordObject

def end_keyword: () -> String?



5628
5629
5630
# File 'lib/prism/node.rb', line 5628

def end_keyword
  end_keyword_loc&.slice
end

#inspect(inspector = NodeInspector.new) ⇒ Object

def inspect(inspector: NodeInspector) -> String



5633
5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
# File 'lib/prism/node.rb', line 5633

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  inspector << "├── else_keyword_loc: #{inspector.location(else_keyword_loc)}\n"
  if (statements = self.statements).nil?
    inspector << "├── statements: ∅\n"
  else
    inspector << "├── statements:\n"
    inspector << statements.inspect(inspector.child_inspector("")).delete_prefix(inspector.prefix)
  end
  inspector << "└── end_keyword_loc: #{inspector.location(end_keyword_loc)}\n"
  inspector.to_str
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



5660
5661
5662
# File 'lib/prism/node.rb', line 5660

def type
  :else_node
end