Class: Prism::FloatNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
lib/prism/node_ext.rb,
ext/prism/api_node.c

Overview

Represents a floating point number literal.

1.0
^^^

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(location) ⇒ FloatNode

def initialize: (location: Location) -> void



6365
6366
6367
# File 'lib/prism/node.rb', line 6365

def initialize(location)
  @location = location
end

Class Method Details

.typeObject

Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.

def self.type: () -> Symbol



6434
6435
6436
# File 'lib/prism/node.rb', line 6434

def self.type
  :float_node
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



6370
6371
6372
# File 'lib/prism/node.rb', line 6370

def accept(visitor)
  visitor.visit_float_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



6375
6376
6377
# File 'lib/prism/node.rb', line 6375

def child_nodes
  []
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



6385
6386
6387
# File 'lib/prism/node.rb', line 6385

def comment_targets
  []
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



6380
6381
6382
# File 'lib/prism/node.rb', line 6380

def compact_child_nodes
  []
end

#copy(**params) ⇒ Object

def copy: (**params) -> FloatNode



6390
6391
6392
6393
6394
# File 'lib/prism/node.rb', line 6390

def copy(**params)
  FloatNode.new(
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array | String | Token | Array | Location]



6400
6401
6402
# File 'lib/prism/node.rb', line 6400

def deconstruct_keys(keys)
  { location: location }
end

#inspect(inspector = NodeInspector.new) ⇒ Object

def inspect(inspector: NodeInspector) -> String



6405
6406
6407
6408
# File 'lib/prism/node.rb', line 6405

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  inspector.to_str
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



6424
6425
6426
# File 'lib/prism/node.rb', line 6424

def type
  :float_node
end

#valueObject

Returns the value of the node as a Ruby Float.



62
63
64
# File 'lib/prism/node_ext.rb', line 62

def value
  Float(slice)
end