Class: Prism::GlobalVariableWriteNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents writing to a global variable.

$foo = 1
^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, name_loc, value, operator_loc, location) ⇒ GlobalVariableWriteNode

def initialize: (name: Symbol, name_loc: Location, value: Node, operator_loc: Location, location: Location) -> void



7369
7370
7371
7372
7373
7374
7375
# File 'lib/prism/node.rb', line 7369

def initialize(name, name_loc, value, operator_loc, location)
  @name = name
  @name_loc = name_loc
  @value = value
  @operator_loc = operator_loc
  @location = location
end

Instance Attribute Details

#nameObject (readonly)

attr_reader name: Symbol



7357
7358
7359
# File 'lib/prism/node.rb', line 7357

def name
  @name
end

#name_locObject (readonly)

attr_reader name_loc: Location



7360
7361
7362
# File 'lib/prism/node.rb', line 7360

def name_loc
  @name_loc
end

#operator_locObject (readonly)

attr_reader operator_loc: Location



7366
7367
7368
# File 'lib/prism/node.rb', line 7366

def operator_loc
  @operator_loc
end

#valueObject (readonly)

attr_reader value: Node



7363
7364
7365
# File 'lib/prism/node.rb', line 7363

def value
  @value
end

Class Method Details

.typeObject

Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.

def self.type: () -> Symbol



7456
7457
7458
# File 'lib/prism/node.rb', line 7456

def self.type
  :global_variable_write_node
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



7378
7379
7380
# File 'lib/prism/node.rb', line 7378

def accept(visitor)
  visitor.visit_global_variable_write_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



7383
7384
7385
# File 'lib/prism/node.rb', line 7383

def child_nodes
  [value]
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



7393
7394
7395
# File 'lib/prism/node.rb', line 7393

def comment_targets
  [name_loc, value, operator_loc]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



7388
7389
7390
# File 'lib/prism/node.rb', line 7388

def compact_child_nodes
  [value]
end

#copy(**params) ⇒ Object

def copy: (**params) -> GlobalVariableWriteNode



7398
7399
7400
7401
7402
7403
7404
7405
7406
# File 'lib/prism/node.rb', line 7398

def copy(**params)
  GlobalVariableWriteNode.new(
    params.fetch(:name) { name },
    params.fetch(:name_loc) { name_loc },
    params.fetch(:value) { value },
    params.fetch(:operator_loc) { operator_loc },
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array | String | Token | Array | Location]



7412
7413
7414
# File 'lib/prism/node.rb', line 7412

def deconstruct_keys(keys)
  { name: name, name_loc: name_loc, value: value, operator_loc: operator_loc, location: location }
end

#inspect(inspector = NodeInspector.new) ⇒ Object

def inspect(inspector: NodeInspector) -> String



7422
7423
7424
7425
7426
7427
7428
7429
7430
# File 'lib/prism/node.rb', line 7422

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  inspector << "├── name: #{name.inspect}\n"
  inspector << "├── name_loc: #{inspector.location(name_loc)}\n"
  inspector << "├── value:\n"
  inspector << inspector.child_node(value, "")
  inspector << "└── operator_loc: #{inspector.location(operator_loc)}\n"
  inspector.to_str
end

#operatorObject

def operator: () -> String



7417
7418
7419
# File 'lib/prism/node.rb', line 7417

def operator
  operator_loc.slice
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



7446
7447
7448
# File 'lib/prism/node.rb', line 7446

def type
  :global_variable_write_node
end