Class: Prism::InstanceVariableOperatorWriteNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::InstanceVariableOperatorWriteNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents assigning to an instance variable using an operator that isn’t ‘=`.
@target += value
^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
-
#name_loc ⇒ Object
readonly
attr_reader name_loc: Location.
-
#operator ⇒ Object
readonly
attr_reader operator: Symbol.
-
#operator_loc ⇒ Object
readonly
attr_reader operator_loc: Location.
-
#value ⇒ Object
readonly
attr_reader value: Node.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> InstanceVariableOperatorWriteNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(name, name_loc, operator_loc, value, operator, location) ⇒ InstanceVariableOperatorWriteNode
constructor
def initialize: (name: Symbol, name_loc: Location, operator_loc: Location, value: Node, operator: Symbol, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(name, name_loc, operator_loc, value, operator, location) ⇒ InstanceVariableOperatorWriteNode
def initialize: (name: Symbol, name_loc: Location, operator_loc: Location, value: Node, operator: Symbol, location: Location) -> void
8661 8662 8663 8664 8665 8666 8667 8668 |
# File 'lib/prism/node.rb', line 8661 def initialize(name, name_loc, operator_loc, value, operator, location) @name = name @name_loc = name_loc @operator_loc = operator_loc @value = value @operator = operator @location = location end |
Instance Attribute Details
#name ⇒ Object (readonly)
attr_reader name: Symbol
8646 8647 8648 |
# File 'lib/prism/node.rb', line 8646 def name @name end |
#name_loc ⇒ Object (readonly)
attr_reader name_loc: Location
8649 8650 8651 |
# File 'lib/prism/node.rb', line 8649 def name_loc @name_loc end |
#operator ⇒ Object (readonly)
attr_reader operator: Symbol
8658 8659 8660 |
# File 'lib/prism/node.rb', line 8658 def operator @operator end |
#operator_loc ⇒ Object (readonly)
attr_reader operator_loc: Location
8652 8653 8654 |
# File 'lib/prism/node.rb', line 8652 def operator_loc @operator_loc end |
#value ⇒ Object (readonly)
attr_reader value: Node
8655 8656 8657 |
# File 'lib/prism/node.rb', line 8655 def value @value end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
8746 8747 8748 |
# File 'lib/prism/node.rb', line 8746 def self.type :instance_variable_operator_write_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
8671 8672 8673 |
# File 'lib/prism/node.rb', line 8671 def accept(visitor) visitor.visit_instance_variable_operator_write_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
8676 8677 8678 |
# File 'lib/prism/node.rb', line 8676 def child_nodes [value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
8686 8687 8688 |
# File 'lib/prism/node.rb', line 8686 def comment_targets [name_loc, operator_loc, value] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
8681 8682 8683 |
# File 'lib/prism/node.rb', line 8681 def compact_child_nodes [value] end |
#copy(**params) ⇒ Object
def copy: (**params) -> InstanceVariableOperatorWriteNode
8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 |
# File 'lib/prism/node.rb', line 8691 def copy(**params) InstanceVariableOperatorWriteNode.new( params.fetch(:name) { name }, params.fetch(:name_loc) { name_loc }, params.fetch(:operator_loc) { operator_loc }, params.fetch(:value) { value }, params.fetch(:operator) { operator }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
8706 8707 8708 |
# File 'lib/prism/node.rb', line 8706 def deconstruct_keys(keys) { name: name, name_loc: name_loc, operator_loc: operator_loc, value: value, operator: operator, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
8711 8712 8713 8714 8715 8716 8717 8718 8719 8720 |
# File 'lib/prism/node.rb', line 8711 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── name: #{name.inspect}\n" inspector << "├── name_loc: #{inspector.location(name_loc)}\n" inspector << "├── operator_loc: #{inspector.location(operator_loc)}\n" inspector << "├── value:\n" inspector << inspector.child_node(value, "│ ") inspector << "└── operator: #{operator.inspect}\n" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
8736 8737 8738 |
# File 'lib/prism/node.rb', line 8736 def type :instance_variable_operator_write_node end |