Class: Prism::InterpolatedMatchLastLineNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
lib/prism/node_ext.rb,
lib/prism/parse_result/newlines.rb,
ext/prism/api_node.c

Overview

Represents a regular expression literal that contains interpolation that is being used in the predicate of a conditional to implicitly match against the last line read by an IO object.

if /foo #{bar} baz/ then end
   ^^^^^^^^^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(source, node_id, location, flags, opening_loc, parts, closing_loc) ⇒ InterpolatedMatchLastLineNode

Initialize a new InterpolatedMatchLastLineNode node.



11246
11247
11248
11249
11250
11251
11252
11253
11254
# File 'lib/prism/node.rb', line 11246

def initialize(source, node_id, location, flags, opening_loc, parts, closing_loc)
  @source = source
  @node_id = node_id
  @location = location
  @flags = flags
  @opening_loc = opening_loc
  @parts = parts
  @closing_loc = closing_loc
end

Instance Attribute Details

#partsObject (readonly)

attr_reader parts: Array[StringNode | EmbeddedStatementsNode | EmbeddedVariableNode]



11365
11366
11367
# File 'lib/prism/node.rb', line 11365

def parts
  @parts
end

Class Method Details

.typeObject

Return a symbol representation of this node type. See Node::type.



11401
11402
11403
# File 'lib/prism/node.rb', line 11401

def self.type
  :interpolated_match_last_line_node
end

Instance Method Details

#===(other) ⇒ Object

Implements case-equality for the node. This is effectively == but without comparing the value of locations. Locations are checked only for presence.



11407
11408
11409
11410
11411
11412
11413
11414
# File 'lib/prism/node.rb', line 11407

def ===(other)
  other.is_a?(InterpolatedMatchLastLineNode) &&
    (flags === other.flags) &&
    (opening_loc.nil? == other.opening_loc.nil?) &&
    (parts.length == other.parts.length) &&
    parts.zip(other.parts).all? { |left, right| left === right } &&
    (closing_loc.nil? == other.closing_loc.nil?)
end

#accept(visitor) ⇒ Object

def accept: (Visitor visitor) -> void



11257
11258
11259
# File 'lib/prism/node.rb', line 11257

def accept(visitor)
  visitor.visit_interpolated_match_last_line_node(self)
end

#ascii_8bit?Boolean

def ascii_8bit?: () -> bool

Returns:



11322
11323
11324
# File 'lib/prism/node.rb', line 11322

def ascii_8bit?
  flags.anybits?(RegularExpressionFlags::ASCII_8BIT)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array



11262
11263
11264
# File 'lib/prism/node.rb', line 11262

def child_nodes
  [*parts]
end

#closingObject

def closing: () -> String



11386
11387
11388
# File 'lib/prism/node.rb', line 11386

def closing
  closing_loc.slice
end

#closing_locObject

attr_reader closing_loc: Location



11368
11369
11370
11371
11372
# File 'lib/prism/node.rb', line 11368

def closing_loc
  location = @closing_loc
  return location if location.is_a?(Location)
  @closing_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



11279
11280
11281
# File 'lib/prism/node.rb', line 11279

def comment_targets
  [opening_loc, *parts, closing_loc] #: Array[Prism::node | Location]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



11274
11275
11276
# File 'lib/prism/node.rb', line 11274

def compact_child_nodes
  [*parts]
end

#copy(node_id: self.node_id, location: self.location, flags: self.flags, opening_loc: self.opening_loc, parts: self.parts, closing_loc: self.closing_loc) ⇒ Object

def copy: (?node_id: Integer, ?location: Location, ?flags: Integer, ?opening_loc: Location, ?parts: Array[StringNode | EmbeddedStatementsNode | EmbeddedVariableNode], ?closing_loc: Location) -> InterpolatedMatchLastLineNode



11284
11285
11286
# File 'lib/prism/node.rb', line 11284

def copy(node_id: self.node_id, location: self.location, flags: self.flags, opening_loc: self.opening_loc, parts: self.parts, closing_loc: self.closing_loc)
  InterpolatedMatchLastLineNode.new(source, node_id, location, flags, opening_loc, parts, closing_loc)
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (Array keys) -> { node_id: Integer, location: Location, opening_loc: Location, parts: Array[StringNode | EmbeddedStatementsNode | EmbeddedVariableNode], closing_loc: Location }



11292
11293
11294
# File 'lib/prism/node.rb', line 11292

def deconstruct_keys(keys)
  { node_id: node_id, location: location, opening_loc: opening_loc, parts: parts, closing_loc: closing_loc }
end

#each_child_nodeObject

def each_child_node: () { (Prism::node) -> void } -> void | () -> Enumerator



11267
11268
11269
11270
11271
# File 'lib/prism/node.rb', line 11267

def each_child_node
  return to_enum(:each_child_node) unless block_given?

  parts.each { |node| yield node }
end

#euc_jp?Boolean

def euc_jp?: () -> bool

Returns:



11317
11318
11319
# File 'lib/prism/node.rb', line 11317

def euc_jp?
  flags.anybits?(RegularExpressionFlags::EUC_JP)
end

#extended?Boolean

def extended?: () -> bool

Returns:



11302
11303
11304
# File 'lib/prism/node.rb', line 11302

def extended?
  flags.anybits?(RegularExpressionFlags::EXTENDED)
end

#forced_binary_encoding?Boolean

def forced_binary_encoding?: () -> bool

Returns:



11342
11343
11344
# File 'lib/prism/node.rb', line 11342

def forced_binary_encoding?
  flags.anybits?(RegularExpressionFlags::FORCED_BINARY_ENCODING)
end

#forced_us_ascii_encoding?Boolean

def forced_us_ascii_encoding?: () -> bool

Returns:



11347
11348
11349
# File 'lib/prism/node.rb', line 11347

def forced_us_ascii_encoding?
  flags.anybits?(RegularExpressionFlags::FORCED_US_ASCII_ENCODING)
end

#forced_utf8_encoding?Boolean

def forced_utf8_encoding?: () -> bool

Returns:



11337
11338
11339
# File 'lib/prism/node.rb', line 11337

def forced_utf8_encoding?
  flags.anybits?(RegularExpressionFlags::FORCED_UTF8_ENCODING)
end

#ignore_case?Boolean

def ignore_case?: () -> bool

Returns:



11297
11298
11299
# File 'lib/prism/node.rb', line 11297

def ignore_case?
  flags.anybits?(RegularExpressionFlags::IGNORE_CASE)
end

#inspectObject

def inspect -> String



11391
11392
11393
# File 'lib/prism/node.rb', line 11391

def inspect
  InspectVisitor.compose(self)
end

#multi_line?Boolean

def multi_line?: () -> bool

Returns:



11307
11308
11309
# File 'lib/prism/node.rb', line 11307

def multi_line?
  flags.anybits?(RegularExpressionFlags::MULTI_LINE)
end

#newline_flag!(lines) ⇒ Object

:nodoc:



122
123
124
125
# File 'lib/prism/parse_result/newlines.rb', line 122

def newline_flag!(lines) # :nodoc:
  first = parts.first
  first.newline_flag!(lines) if first
end

#once?Boolean

def once?: () -> bool

Returns:



11312
11313
11314
# File 'lib/prism/node.rb', line 11312

def once?
  flags.anybits?(RegularExpressionFlags::ONCE)
end

#openingObject

def opening: () -> String



11381
11382
11383
# File 'lib/prism/node.rb', line 11381

def opening
  opening_loc.slice
end

#opening_locObject

attr_reader opening_loc: Location



11352
11353
11354
11355
11356
# File 'lib/prism/node.rb', line 11352

def opening_loc
  location = @opening_loc
  return location if location.is_a?(Location)
  @opening_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#save_closing_loc(repository) ⇒ Object

Save the closing_loc location using the given saved source so that it can be retrieved later.



11376
11377
11378
# File 'lib/prism/node.rb', line 11376

def save_closing_loc(repository)
  repository.enter(node_id, :closing_loc)
end

#save_opening_loc(repository) ⇒ Object

Save the opening_loc location using the given saved source so that it can be retrieved later.



11360
11361
11362
# File 'lib/prism/node.rb', line 11360

def save_opening_loc(repository)
  repository.enter(node_id, :opening_loc)
end

#typeObject

Return a symbol representation of this node type. See ‘Node#type`.



11396
11397
11398
# File 'lib/prism/node.rb', line 11396

def type
  :interpolated_match_last_line_node
end

#utf_8?Boolean

def utf_8?: () -> bool

Returns:



11332
11333
11334
# File 'lib/prism/node.rb', line 11332

def utf_8?
  flags.anybits?(RegularExpressionFlags::UTF_8)
end

#windows_31j?Boolean

def windows_31j?: () -> bool

Returns:



11327
11328
11329
# File 'lib/prism/node.rb', line 11327

def windows_31j?
  flags.anybits?(RegularExpressionFlags::WINDOWS_31J)
end