Class: Prism::LexCompat::Heredoc::PlainHeredoc

Inherits:
Object
  • Object
show all
Defined in:
lib/prism/lex_compat.rb

Overview

Heredocs that are no dash or tilde heredocs are just a list of tokens. We need to keep them around so that we can insert them in the correct order back into the token stream and set the state of the last token to the state that the heredoc was opened in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializePlainHeredoc

Returns a new instance of PlainHeredoc.



261
262
263
# File 'lib/prism/lex_compat.rb', line 261

def initialize
  @tokens = []
end

Instance Attribute Details

#tokensObject (readonly)

:nodoc:



259
260
261
# File 'lib/prism/lex_compat.rb', line 259

def tokens
  @tokens
end

Instance Method Details

#<<(token) ⇒ Object



265
266
267
# File 'lib/prism/lex_compat.rb', line 265

def <<(token)
  tokens << token
end

#to_aObject



269
270
271
# File 'lib/prism/lex_compat.rb', line 269

def to_a
  tokens
end