Class: Prism::LocalVariableTargetNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::LocalVariableTargetNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents writing to a local variable in a context that doesn’t have an explicit value.
foo, bar = baz
^^^ ^^^
Instance Attribute Summary collapse
-
#depth ⇒ Object
readonly
attr_reader depth: Integer.
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> LocalVariableTargetNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(name, depth, location) ⇒ LocalVariableTargetNode
constructor
def initialize: (name: Symbol, depth: Integer, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(name, depth, location) ⇒ LocalVariableTargetNode
def initialize: (name: Symbol, depth: Integer, location: Location) -> void
10704 10705 10706 10707 10708 |
# File 'lib/prism/node.rb', line 10704 def initialize(name, depth, location) @name = name @depth = depth @location = location end |
Instance Attribute Details
#depth ⇒ Object (readonly)
attr_reader depth: Integer
10701 10702 10703 |
# File 'lib/prism/node.rb', line 10701 def depth @depth end |
#name ⇒ Object (readonly)
attr_reader name: Symbol
10698 10699 10700 |
# File 'lib/prism/node.rb', line 10698 def name @name end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
10779 10780 10781 |
# File 'lib/prism/node.rb', line 10779 def self.type :local_variable_target_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
10711 10712 10713 |
# File 'lib/prism/node.rb', line 10711 def accept(visitor) visitor.visit_local_variable_target_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
10716 10717 10718 |
# File 'lib/prism/node.rb', line 10716 def child_nodes [] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
10726 10727 10728 |
# File 'lib/prism/node.rb', line 10726 def comment_targets [] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
10721 10722 10723 |
# File 'lib/prism/node.rb', line 10721 def compact_child_nodes [] end |
#copy(**params) ⇒ Object
def copy: (**params) -> LocalVariableTargetNode
10731 10732 10733 10734 10735 10736 10737 |
# File 'lib/prism/node.rb', line 10731 def copy(**params) LocalVariableTargetNode.new( params.fetch(:name) { name }, params.fetch(:depth) { depth }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
10743 10744 10745 |
# File 'lib/prism/node.rb', line 10743 def deconstruct_keys(keys) { name: name, depth: depth, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
10748 10749 10750 10751 10752 10753 |
# File 'lib/prism/node.rb', line 10748 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── name: #{name.inspect}\n" inspector << "└── depth: #{depth.inspect}\n" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
10769 10770 10771 |
# File 'lib/prism/node.rb', line 10769 def type :local_variable_target_node end |