Class: Prism::MatchLastLineNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::MatchLastLineNode
- Defined in:
- lib/prism/node.rb,
lib/prism/node_ext.rb,
ext/prism/api_node.c
Overview
Represents a regular expression literal used in the predicate of a conditional to implicitly match against the last line read by an IO object.
if /foo/i then end
^^^^^^
Instance Attribute Summary collapse
-
#closing_loc ⇒ Object
readonly
attr_reader closing_loc: Location.
-
#content_loc ⇒ Object
readonly
attr_reader content_loc: Location.
-
#flags ⇒ Object
readonly
Returns the value of attribute flags.
-
#opening_loc ⇒ Object
readonly
attr_reader opening_loc: Location.
-
#unescaped ⇒ Object
readonly
attr_reader unescaped: String.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#ascii_8bit? ⇒ Boolean
def ascii_8bit?: () -> bool.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#closing ⇒ Object
def closing: () -> String.
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#content ⇒ Object
def content: () -> String.
-
#copy(**params) ⇒ Object
def copy: (**params) -> MatchLastLineNode.
- #deconstruct_keys(keys) ⇒ Object
-
#euc_jp? ⇒ Boolean
def euc_jp?: () -> bool.
-
#extended? ⇒ Boolean
def extended?: () -> bool.
-
#forced_binary_encoding? ⇒ Boolean
def forced_binary_encoding?: () -> bool.
-
#forced_us_ascii_encoding? ⇒ Boolean
def forced_us_ascii_encoding?: () -> bool.
-
#forced_utf8_encoding? ⇒ Boolean
def forced_utf8_encoding?: () -> bool.
-
#ignore_case? ⇒ Boolean
def ignore_case?: () -> bool.
-
#initialize(flags, opening_loc, content_loc, closing_loc, unescaped, location) ⇒ MatchLastLineNode
constructor
def initialize: (flags: Integer, opening_loc: Location, content_loc: Location, closing_loc: Location, unescaped: String, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#multi_line? ⇒ Boolean
def multi_line?: () -> bool.
-
#once? ⇒ Boolean
def once?: () -> bool.
-
#opening ⇒ Object
def opening: () -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
-
#utf_8? ⇒ Boolean
def utf_8?: () -> bool.
-
#windows_31j? ⇒ Boolean
def windows_31j?: () -> bool.
Constructor Details
#initialize(flags, opening_loc, content_loc, closing_loc, unescaped, location) ⇒ MatchLastLineNode
def initialize: (flags: Integer, opening_loc: Location, content_loc: Location, closing_loc: Location, unescaped: String, location: Location) -> void
11429 11430 11431 11432 11433 11434 11435 11436 |
# File 'lib/prism/node.rb', line 11429 def initialize(flags, opening_loc, content_loc, closing_loc, unescaped, location) @flags = flags @opening_loc = opening_loc @content_loc = content_loc @closing_loc = closing_loc @unescaped = unescaped @location = location end |
Instance Attribute Details
#closing_loc ⇒ Object (readonly)
attr_reader closing_loc: Location
11423 11424 11425 |
# File 'lib/prism/node.rb', line 11423 def closing_loc @closing_loc end |
#content_loc ⇒ Object (readonly)
attr_reader content_loc: Location
11420 11421 11422 |
# File 'lib/prism/node.rb', line 11420 def content_loc @content_loc end |
#flags ⇒ Object (readonly)
Returns the value of attribute flags.
11414 11415 11416 |
# File 'lib/prism/node.rb', line 11414 def flags @flags end |
#opening_loc ⇒ Object (readonly)
attr_reader opening_loc: Location
11417 11418 11419 |
# File 'lib/prism/node.rb', line 11417 def opening_loc @opening_loc end |
#unescaped ⇒ Object (readonly)
attr_reader unescaped: String
11426 11427 11428 |
# File 'lib/prism/node.rb', line 11426 def unescaped @unescaped end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
11584 11585 11586 |
# File 'lib/prism/node.rb', line 11584 def self.type :match_last_line_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
11439 11440 11441 |
# File 'lib/prism/node.rb', line 11439 def accept(visitor) visitor.visit_match_last_line_node(self) end |
#ascii_8bit? ⇒ Boolean
def ascii_8bit?: () -> bool
11504 11505 11506 |
# File 'lib/prism/node.rb', line 11504 def ascii_8bit? flags.anybits?(RegularExpressionFlags::ASCII_8BIT) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
11444 11445 11446 |
# File 'lib/prism/node.rb', line 11444 def child_nodes [] end |
#closing ⇒ Object
def closing: () -> String
11544 11545 11546 |
# File 'lib/prism/node.rb', line 11544 def closing closing_loc.slice end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
11454 11455 11456 |
# File 'lib/prism/node.rb', line 11454 def comment_targets [opening_loc, content_loc, closing_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
11449 11450 11451 |
# File 'lib/prism/node.rb', line 11449 def compact_child_nodes [] end |
#content ⇒ Object
def content: () -> String
11539 11540 11541 |
# File 'lib/prism/node.rb', line 11539 def content content_loc.slice end |
#copy(**params) ⇒ Object
def copy: (**params) -> MatchLastLineNode
11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/prism/node.rb', line 11459 def copy(**params) MatchLastLineNode.new( params.fetch(:flags) { flags }, params.fetch(:opening_loc) { opening_loc }, params.fetch(:content_loc) { content_loc }, params.fetch(:closing_loc) { closing_loc }, params.fetch(:unescaped) { unescaped }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
11474 11475 11476 |
# File 'lib/prism/node.rb', line 11474 def deconstruct_keys(keys) { flags: flags, opening_loc: opening_loc, content_loc: content_loc, closing_loc: closing_loc, unescaped: unescaped, location: location } end |
#euc_jp? ⇒ Boolean
def euc_jp?: () -> bool
11499 11500 11501 |
# File 'lib/prism/node.rb', line 11499 def euc_jp? flags.anybits?(RegularExpressionFlags::EUC_JP) end |
#extended? ⇒ Boolean
def extended?: () -> bool
11484 11485 11486 |
# File 'lib/prism/node.rb', line 11484 def extended? flags.anybits?(RegularExpressionFlags::EXTENDED) end |
#forced_binary_encoding? ⇒ Boolean
def forced_binary_encoding?: () -> bool
11524 11525 11526 |
# File 'lib/prism/node.rb', line 11524 def forced_binary_encoding? flags.anybits?(RegularExpressionFlags::FORCED_BINARY_ENCODING) end |
#forced_us_ascii_encoding? ⇒ Boolean
def forced_us_ascii_encoding?: () -> bool
11529 11530 11531 |
# File 'lib/prism/node.rb', line 11529 def forced_us_ascii_encoding? flags.anybits?(RegularExpressionFlags::FORCED_US_ASCII_ENCODING) end |
#forced_utf8_encoding? ⇒ Boolean
def forced_utf8_encoding?: () -> bool
11519 11520 11521 |
# File 'lib/prism/node.rb', line 11519 def forced_utf8_encoding? flags.anybits?(RegularExpressionFlags::FORCED_UTF8_ENCODING) end |
#ignore_case? ⇒ Boolean
def ignore_case?: () -> bool
11479 11480 11481 |
# File 'lib/prism/node.rb', line 11479 def ignore_case? flags.anybits?(RegularExpressionFlags::IGNORE_CASE) end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 |
# File 'lib/prism/node.rb', line 11549 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) flags = [("ignore_case" if ignore_case?), ("extended" if extended?), ("multi_line" if multi_line?), ("once" if once?), ("euc_jp" if euc_jp?), ("ascii_8bit" if ascii_8bit?), ("windows_31j" if windows_31j?), ("utf_8" if utf_8?), ("forced_utf8_encoding" if forced_utf8_encoding?), ("forced_binary_encoding" if forced_binary_encoding?), ("forced_us_ascii_encoding" if forced_us_ascii_encoding?)].compact inspector << "├── flags: #{flags.empty? ? "∅" : flags.join(", ")}\n" inspector << "├── opening_loc: #{inspector.location(opening_loc)}\n" inspector << "├── content_loc: #{inspector.location(content_loc)}\n" inspector << "├── closing_loc: #{inspector.location(closing_loc)}\n" inspector << "└── unescaped: #{unescaped.inspect}\n" inspector.to_str end |
#multi_line? ⇒ Boolean
def multi_line?: () -> bool
11489 11490 11491 |
# File 'lib/prism/node.rb', line 11489 def multi_line? flags.anybits?(RegularExpressionFlags::MULTI_LINE) end |
#once? ⇒ Boolean
def once?: () -> bool
11494 11495 11496 |
# File 'lib/prism/node.rb', line 11494 def once? flags.anybits?(RegularExpressionFlags::ONCE) end |
#opening ⇒ Object
def opening: () -> String
11534 11535 11536 |
# File 'lib/prism/node.rb', line 11534 def opening opening_loc.slice end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
11574 11575 11576 |
# File 'lib/prism/node.rb', line 11574 def type :match_last_line_node end |
#utf_8? ⇒ Boolean
def utf_8?: () -> bool
11514 11515 11516 |
# File 'lib/prism/node.rb', line 11514 def utf_8? flags.anybits?(RegularExpressionFlags::UTF_8) end |
#windows_31j? ⇒ Boolean
def windows_31j?: () -> bool
11509 11510 11511 |
# File 'lib/prism/node.rb', line 11509 def windows_31j? flags.anybits?(RegularExpressionFlags::WINDOWS_31J) end |