Class: Prism::MatchWriteNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::MatchWriteNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents writing local variables using a regular expression match with named capture groups.
/(?<foo>bar)/ =~ baz
^^^^^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#call ⇒ Object
readonly
attr_reader call: CallNode.
-
#targets ⇒ Object
readonly
attr_reader targets: Array.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> MatchWriteNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(call, targets, location) ⇒ MatchWriteNode
constructor
def initialize: (call: CallNode, targets: Array, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(call, targets, location) ⇒ MatchWriteNode
def initialize: (call: CallNode, targets: Array, location: Location) -> void
11812 11813 11814 11815 11816 |
# File 'lib/prism/node.rb', line 11812 def initialize(call, targets, location) @call = call @targets = targets @location = location end |
Instance Attribute Details
#call ⇒ Object (readonly)
attr_reader call: CallNode
11806 11807 11808 |
# File 'lib/prism/node.rb', line 11806 def call @call end |
#targets ⇒ Object (readonly)
attr_reader targets: Array
11809 11810 11811 |
# File 'lib/prism/node.rb', line 11809 def targets @targets end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
11888 11889 11890 |
# File 'lib/prism/node.rb', line 11888 def self.type :match_write_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
11819 11820 11821 |
# File 'lib/prism/node.rb', line 11819 def accept(visitor) visitor.visit_match_write_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
11824 11825 11826 |
# File 'lib/prism/node.rb', line 11824 def child_nodes [call, *targets] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
11834 11835 11836 |
# File 'lib/prism/node.rb', line 11834 def comment_targets [call, *targets] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
11829 11830 11831 |
# File 'lib/prism/node.rb', line 11829 def compact_child_nodes [call, *targets] end |
#copy(**params) ⇒ Object
def copy: (**params) -> MatchWriteNode
11839 11840 11841 11842 11843 11844 11845 |
# File 'lib/prism/node.rb', line 11839 def copy(**params) MatchWriteNode.new( params.fetch(:call) { call }, params.fetch(:targets) { targets }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
11851 11852 11853 |
# File 'lib/prism/node.rb', line 11851 def deconstruct_keys(keys) { call: call, targets: targets, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
11856 11857 11858 11859 11860 11861 11862 |
# File 'lib/prism/node.rb', line 11856 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── call:\n" inspector << inspector.child_node(call, "│ ") inspector << "└── targets: #{inspector.list("#{inspector.prefix} ", targets)}" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
11878 11879 11880 |
# File 'lib/prism/node.rb', line 11878 def type :match_write_node end |