Class: Prism::PreExecutionNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents the use of the BEGIN keyword.

BEGIN { foo }
^^^^^^^^^^^^^

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(source, node_id, location, flags, statements, keyword_loc, opening_loc, closing_loc) ⇒ PreExecutionNode

Initialize a new PreExecutionNode node.



15844
15845
15846
15847
15848
15849
15850
15851
15852
15853
# File 'lib/prism/node.rb', line 15844

def initialize(source, node_id, location, flags, statements, keyword_loc, opening_loc, closing_loc)
  @source = source
  @node_id = node_id
  @location = location
  @flags = flags
  @statements = statements
  @keyword_loc = keyword_loc
  @opening_loc = opening_loc
  @closing_loc = closing_loc
end

Instance Attribute Details

#statementsObject (readonly)

attr_reader statements: StatementsNode?



15898
15899
15900
# File 'lib/prism/node.rb', line 15898

def statements
  @statements
end

Class Method Details

.typeObject

Return a symbol representation of this node type. See Node::type.



15965
15966
15967
# File 'lib/prism/node.rb', line 15965

def self.type
  :pre_execution_node
end

Instance Method Details

#===(other) ⇒ Object

Implements case-equality for the node. This is effectively == but without comparing the value of locations. Locations are checked only for presence.



15971
15972
15973
15974
15975
15976
15977
# File 'lib/prism/node.rb', line 15971

def ===(other)
  other.is_a?(PreExecutionNode) &&
    (statements === other.statements) &&
    (keyword_loc.nil? == other.keyword_loc.nil?) &&
    (opening_loc.nil? == other.opening_loc.nil?) &&
    (closing_loc.nil? == other.closing_loc.nil?)
end

#accept(visitor) ⇒ Object

def accept: (Visitor visitor) -> void



15856
15857
15858
# File 'lib/prism/node.rb', line 15856

def accept(visitor)
  visitor.visit_pre_execution_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array



15861
15862
15863
# File 'lib/prism/node.rb', line 15861

def child_nodes
  [statements]
end

#closingObject

def closing: () -> String



15950
15951
15952
# File 'lib/prism/node.rb', line 15950

def closing
  closing_loc.slice
end

#closing_locObject

attr_reader closing_loc: Location



15927
15928
15929
15930
15931
# File 'lib/prism/node.rb', line 15927

def closing_loc
  location = @closing_loc
  return location if location.is_a?(Location)
  @closing_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



15880
15881
15882
# File 'lib/prism/node.rb', line 15880

def comment_targets
  [*statements, keyword_loc, opening_loc, closing_loc] #: Array[Prism::node | Location]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



15873
15874
15875
15876
15877
# File 'lib/prism/node.rb', line 15873

def compact_child_nodes
  compact = [] #: Array[Prism::node]
  compact << statements if statements
  compact
end

#copy(node_id: self.node_id, location: self.location, flags: self.flags, statements: self.statements, keyword_loc: self.keyword_loc, opening_loc: self.opening_loc, closing_loc: self.closing_loc) ⇒ Object

def copy: (?node_id: Integer, ?location: Location, ?flags: Integer, ?statements: StatementsNode?, ?keyword_loc: Location, ?opening_loc: Location, ?closing_loc: Location) -> PreExecutionNode



15885
15886
15887
# File 'lib/prism/node.rb', line 15885

def copy(node_id: self.node_id, location: self.location, flags: self.flags, statements: self.statements, keyword_loc: self.keyword_loc, opening_loc: self.opening_loc, closing_loc: self.closing_loc)
  PreExecutionNode.new(source, node_id, location, flags, statements, keyword_loc, opening_loc, closing_loc)
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (Array keys) -> { node_id: Integer, location: Location, statements: StatementsNode?, keyword_loc: Location, opening_loc: Location, closing_loc: Location }



15893
15894
15895
# File 'lib/prism/node.rb', line 15893

def deconstruct_keys(keys)
  { node_id: node_id, location: location, statements: statements, keyword_loc: keyword_loc, opening_loc: opening_loc, closing_loc: closing_loc }
end

#each_child_node {|statements| ... } ⇒ Object

def each_child_node: () { (Prism::node) -> void } -> void | () -> Enumerator

Yields:



15866
15867
15868
15869
15870
# File 'lib/prism/node.rb', line 15866

def each_child_node
  return to_enum(:each_child_node) unless block_given?

  yield statements if statements
end

#inspectObject

def inspect -> String



15955
15956
15957
# File 'lib/prism/node.rb', line 15955

def inspect
  InspectVisitor.compose(self)
end

#keywordObject

def keyword: () -> String



15940
15941
15942
# File 'lib/prism/node.rb', line 15940

def keyword
  keyword_loc.slice
end

#keyword_locObject

attr_reader keyword_loc: Location



15901
15902
15903
15904
15905
# File 'lib/prism/node.rb', line 15901

def keyword_loc
  location = @keyword_loc
  return location if location.is_a?(Location)
  @keyword_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#openingObject

def opening: () -> String



15945
15946
15947
# File 'lib/prism/node.rb', line 15945

def opening
  opening_loc.slice
end

#opening_locObject

attr_reader opening_loc: Location



15914
15915
15916
15917
15918
# File 'lib/prism/node.rb', line 15914

def opening_loc
  location = @opening_loc
  return location if location.is_a?(Location)
  @opening_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF)
end

#save_closing_loc(repository) ⇒ Object

Save the closing_loc location using the given saved source so that it can be retrieved later.



15935
15936
15937
# File 'lib/prism/node.rb', line 15935

def save_closing_loc(repository)
  repository.enter(node_id, :closing_loc)
end

#save_keyword_loc(repository) ⇒ Object

Save the keyword_loc location using the given saved source so that it can be retrieved later.



15909
15910
15911
# File 'lib/prism/node.rb', line 15909

def save_keyword_loc(repository)
  repository.enter(node_id, :keyword_loc)
end

#save_opening_loc(repository) ⇒ Object

Save the opening_loc location using the given saved source so that it can be retrieved later.



15922
15923
15924
# File 'lib/prism/node.rb', line 15922

def save_opening_loc(repository)
  repository.enter(node_id, :opening_loc)
end

#typeObject

Return a symbol representation of this node type. See ‘Node#type`.



15960
15961
15962
# File 'lib/prism/node.rb', line 15960

def type
  :pre_execution_node
end