Class: Prism::SourceEncodingNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::SourceEncodingNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents the use of the __ENCODING__ keyword.
__ENCODING__
^^^^^^^^^^^^
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> SourceEncodingNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(location) ⇒ SourceEncodingNode
constructor
def initialize: (location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(location) ⇒ SourceEncodingNode
def initialize: (location: Location) -> void
14801 14802 14803 |
# File 'lib/prism/node.rb', line 14801 def initialize(location) @location = location end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
14870 14871 14872 |
# File 'lib/prism/node.rb', line 14870 def self.type :source_encoding_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
14806 14807 14808 |
# File 'lib/prism/node.rb', line 14806 def accept(visitor) visitor.visit_source_encoding_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
14811 14812 14813 |
# File 'lib/prism/node.rb', line 14811 def child_nodes [] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
14821 14822 14823 |
# File 'lib/prism/node.rb', line 14821 def comment_targets [] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
14816 14817 14818 |
# File 'lib/prism/node.rb', line 14816 def compact_child_nodes [] end |
#copy(**params) ⇒ Object
def copy: (**params) -> SourceEncodingNode
14826 14827 14828 14829 14830 |
# File 'lib/prism/node.rb', line 14826 def copy(**params) SourceEncodingNode.new( params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
14836 14837 14838 |
# File 'lib/prism/node.rb', line 14836 def deconstruct_keys(keys) { location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
14841 14842 14843 14844 |
# File 'lib/prism/node.rb', line 14841 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
14860 14861 14862 |
# File 'lib/prism/node.rb', line 14860 def type :source_encoding_node end |