Class: Prism::StringNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::StringNode
- Defined in:
- lib/prism/node.rb,
lib/prism/node_ext.rb,
ext/prism/api_node.c
Overview
Represents a string literal, a string contained within a ‘%w` list, or plain string content within an interpolated string.
"foo"
^^^^^
%w[foo]
^^^
"foo #{bar} baz"
^^^^ ^^^^
Instance Attribute Summary collapse
-
#unescaped ⇒ Object
readonly
attr_reader unescaped: String.
Class Method Summary collapse
-
.type ⇒ Object
Return a symbol representation of this node type.
Instance Method Summary collapse
-
#===(other) ⇒ Object
Implements case-equality for the node.
-
#accept(visitor) ⇒ Object
def accept: (Visitor visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array.
-
#closing ⇒ Object
def closing: () -> String?.
-
#closing_loc ⇒ Object
attr_reader closing_loc: Location?.
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#content ⇒ Object
def content: () -> String.
-
#content_loc ⇒ Object
attr_reader content_loc: Location.
-
#copy(node_id: self.node_id, location: self.location, flags: self.flags, opening_loc: self.opening_loc, content_loc: self.content_loc, closing_loc: self.closing_loc, unescaped: self.unescaped) ⇒ Object
def copy: (?node_id: Integer, ?location: Location, ?flags: Integer, ?opening_loc: Location?, ?content_loc: Location, ?closing_loc: Location?, ?unescaped: String) -> StringNode.
-
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (Array keys) -> { node_id: Integer, location: Location, opening_loc: Location?, content_loc: Location, closing_loc: Location?, unescaped: String }.
-
#each_child_node ⇒ Object
def each_child_node: () { (Prism::node) -> void } -> void | () -> Enumerator.
-
#forced_binary_encoding? ⇒ Boolean
def forced_binary_encoding?: () -> bool.
-
#forced_utf8_encoding? ⇒ Boolean
def forced_utf8_encoding?: () -> bool.
-
#frozen? ⇒ Boolean
def frozen?: () -> bool.
-
#initialize(source, node_id, location, flags, opening_loc, content_loc, closing_loc, unescaped) ⇒ StringNode
constructor
Initialize a new StringNode node.
-
#inspect ⇒ Object
def inspect -> String.
-
#mutable? ⇒ Boolean
def mutable?: () -> bool.
-
#opening ⇒ Object
def opening: () -> String?.
-
#opening_loc ⇒ Object
attr_reader opening_loc: Location?.
-
#save_closing_loc(repository) ⇒ Object
Save the closing_loc location using the given saved source so that it can be retrieved later.
-
#save_content_loc(repository) ⇒ Object
Save the content_loc location using the given saved source so that it can be retrieved later.
-
#save_opening_loc(repository) ⇒ Object
Save the opening_loc location using the given saved source so that it can be retrieved later.
-
#to_interpolated ⇒ Object
Occasionally it’s helpful to treat a string as if it were interpolated so that there’s a consistent interface for working with strings.
-
#type ⇒ Object
Return a symbol representation of this node type.
Constructor Details
#initialize(source, node_id, location, flags, opening_loc, content_loc, closing_loc, unescaped) ⇒ StringNode
Initialize a new StringNode node.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/prism/node.rb', line 18118 def initialize(source, node_id, location, flags, opening_loc, content_loc, closing_loc, unescaped) @source = source @node_id = node_id @location = location @flags = flags @opening_loc = opening_loc @content_loc = content_loc @closing_loc = closing_loc @unescaped = unescaped end |
Instance Attribute Details
#unescaped ⇒ Object (readonly)
attr_reader unescaped: String
18240 18241 18242 |
# File 'lib/prism/node.rb', line 18240 def unescaped @unescaped end |
Class Method Details
.type ⇒ Object
Return a symbol representation of this node type. See Node::type.
18268 18269 18270 |
# File 'lib/prism/node.rb', line 18268 def self.type :string_node end |
Instance Method Details
#===(other) ⇒ Object
Implements case-equality for the node. This is effectively == but without comparing the value of locations. Locations are checked only for presence.
18274 18275 18276 18277 18278 18279 18280 18281 |
# File 'lib/prism/node.rb', line 18274 def ===(other) other.is_a?(StringNode) && (flags === other.flags) && (opening_loc.nil? == other.opening_loc.nil?) && (content_loc.nil? == other.content_loc.nil?) && (closing_loc.nil? == other.closing_loc.nil?) && (unescaped === other.unescaped) end |
#accept(visitor) ⇒ Object
def accept: (Visitor visitor) -> void
18130 18131 18132 |
# File 'lib/prism/node.rb', line 18130 def accept(visitor) visitor.visit_string_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array
18135 18136 18137 |
# File 'lib/prism/node.rb', line 18135 def child_nodes [] end |
#closing ⇒ Object
def closing: () -> String?
18253 18254 18255 |
# File 'lib/prism/node.rb', line 18253 def closing closing_loc&.slice end |
#closing_loc ⇒ Object
attr_reader closing_loc: Location?
18221 18222 18223 18224 18225 18226 18227 18228 18229 18230 18231 |
# File 'lib/prism/node.rb', line 18221 def closing_loc location = @closing_loc case location when nil nil when Location location else @closing_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF) end end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
18151 18152 18153 |
# File 'lib/prism/node.rb', line 18151 def comment_targets [*opening_loc, content_loc, *closing_loc] #: Array[Prism::node | Location] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
18146 18147 18148 |
# File 'lib/prism/node.rb', line 18146 def compact_child_nodes [] end |
#content ⇒ Object
def content: () -> String
18248 18249 18250 |
# File 'lib/prism/node.rb', line 18248 def content content_loc.slice end |
#content_loc ⇒ Object
attr_reader content_loc: Location
18208 18209 18210 18211 18212 |
# File 'lib/prism/node.rb', line 18208 def content_loc location = @content_loc return location if location.is_a?(Location) @content_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF) end |
#copy(node_id: self.node_id, location: self.location, flags: self.flags, opening_loc: self.opening_loc, content_loc: self.content_loc, closing_loc: self.closing_loc, unescaped: self.unescaped) ⇒ Object
def copy: (?node_id: Integer, ?location: Location, ?flags: Integer, ?opening_loc: Location?, ?content_loc: Location, ?closing_loc: Location?, ?unescaped: String) -> StringNode
18156 18157 18158 |
# File 'lib/prism/node.rb', line 18156 def copy(node_id: self.node_id, location: self.location, flags: self.flags, opening_loc: self.opening_loc, content_loc: self.content_loc, closing_loc: self.closing_loc, unescaped: self.unescaped) StringNode.new(source, node_id, location, flags, opening_loc, content_loc, closing_loc, unescaped) end |
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (Array keys) -> { node_id: Integer, location: Location, opening_loc: Location?, content_loc: Location, closing_loc: Location?, unescaped: String }
18164 18165 18166 |
# File 'lib/prism/node.rb', line 18164 def deconstruct_keys(keys) { node_id: node_id, location: location, opening_loc: opening_loc, content_loc: content_loc, closing_loc: closing_loc, unescaped: unescaped } end |
#each_child_node ⇒ Object
def each_child_node: () { (Prism::node) -> void } -> void | () -> Enumerator
18140 18141 18142 18143 |
# File 'lib/prism/node.rb', line 18140 def each_child_node return to_enum(:each_child_node) unless block_given? end |
#forced_binary_encoding? ⇒ Boolean
def forced_binary_encoding?: () -> bool
18174 18175 18176 |
# File 'lib/prism/node.rb', line 18174 def forced_binary_encoding? flags.anybits?(StringFlags::FORCED_BINARY_ENCODING) end |
#forced_utf8_encoding? ⇒ Boolean
def forced_utf8_encoding?: () -> bool
18169 18170 18171 |
# File 'lib/prism/node.rb', line 18169 def forced_utf8_encoding? flags.anybits?(StringFlags::FORCED_UTF8_ENCODING) end |
#frozen? ⇒ Boolean
def frozen?: () -> bool
18179 18180 18181 |
# File 'lib/prism/node.rb', line 18179 def frozen? flags.anybits?(StringFlags::FROZEN) end |
#inspect ⇒ Object
def inspect -> String
18258 18259 18260 |
# File 'lib/prism/node.rb', line 18258 def inspect InspectVisitor.compose(self) end |
#mutable? ⇒ Boolean
def mutable?: () -> bool
18184 18185 18186 |
# File 'lib/prism/node.rb', line 18184 def mutable? flags.anybits?(StringFlags::MUTABLE) end |
#opening ⇒ Object
def opening: () -> String?
18243 18244 18245 |
# File 'lib/prism/node.rb', line 18243 def opening opening_loc&.slice end |
#opening_loc ⇒ Object
attr_reader opening_loc: Location?
18189 18190 18191 18192 18193 18194 18195 18196 18197 18198 18199 |
# File 'lib/prism/node.rb', line 18189 def opening_loc location = @opening_loc case location when nil nil when Location location else @opening_loc = Location.new(source, location >> 32, location & 0xFFFFFFFF) end end |
#save_closing_loc(repository) ⇒ Object
Save the closing_loc location using the given saved source so that it can be retrieved later.
18235 18236 18237 |
# File 'lib/prism/node.rb', line 18235 def save_closing_loc(repository) repository.enter(node_id, :closing_loc) unless @closing_loc.nil? end |
#save_content_loc(repository) ⇒ Object
Save the content_loc location using the given saved source so that it can be retrieved later.
18216 18217 18218 |
# File 'lib/prism/node.rb', line 18216 def save_content_loc(repository) repository.enter(node_id, :content_loc) end |
#save_opening_loc(repository) ⇒ Object
Save the opening_loc location using the given saved source so that it can be retrieved later.
18203 18204 18205 |
# File 'lib/prism/node.rb', line 18203 def save_opening_loc(repository) repository.enter(node_id, :opening_loc) unless @opening_loc.nil? end |
#to_interpolated ⇒ Object
Occasionally it’s helpful to treat a string as if it were interpolated so that there’s a consistent interface for working with strings.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/prism/node_ext.rb', line 75 def to_interpolated InterpolatedStringNode.new( source, -1, location, frozen? ? InterpolatedStringNodeFlags::FROZEN : 0, opening_loc, [copy(location: content_loc, opening_loc: nil, closing_loc: nil)], closing_loc ) end |
#type ⇒ Object
Return a symbol representation of this node type. See ‘Node#type`.
18263 18264 18265 |
# File 'lib/prism/node.rb', line 18263 def type :string_node end |