Class: Prism::WhenNode

Inherits:
PrismNode
  • Object
show all
Defined in:
lib/prism/node.rb,
ext/prism/api_node.c

Overview

Represents the use of the ‘when` keyword within a case statement.

case true
when true
^^^^^^^^^
end

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(keyword_loc, conditions, statements, location) ⇒ WhenNode

def initialize: (keyword_loc: Location, conditions: Array, statements: StatementsNode?, location: Location) -> void



16776
16777
16778
16779
16780
16781
# File 'lib/prism/node.rb', line 16776

def initialize(keyword_loc, conditions, statements, location)
  @keyword_loc = keyword_loc
  @conditions = conditions
  @statements = statements
  @location = location
end

Instance Attribute Details

#conditionsObject (readonly)

attr_reader conditions: Array



16770
16771
16772
# File 'lib/prism/node.rb', line 16770

def conditions
  @conditions
end

#keyword_locObject (readonly)

attr_reader keyword_loc: Location



16767
16768
16769
# File 'lib/prism/node.rb', line 16767

def keyword_loc
  @keyword_loc
end

#statementsObject (readonly)

attr_reader statements: StatementsNode?



16773
16774
16775
# File 'lib/prism/node.rb', line 16773

def statements
  @statements
end

Class Method Details

.typeObject

Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.

def self.type: () -> Symbol



16867
16868
16869
# File 'lib/prism/node.rb', line 16867

def self.type
  :when_node
end

Instance Method Details

#accept(visitor) ⇒ Object

def accept: (visitor: Visitor) -> void



16784
16785
16786
# File 'lib/prism/node.rb', line 16784

def accept(visitor)
  visitor.visit_when_node(self)
end

#child_nodesObject Also known as: deconstruct

def child_nodes: () -> Array[nil | Node]



16789
16790
16791
# File 'lib/prism/node.rb', line 16789

def child_nodes
  [*conditions, statements]
end

#comment_targetsObject

def comment_targets: () -> Array[Node | Location]



16802
16803
16804
# File 'lib/prism/node.rb', line 16802

def comment_targets
  [keyword_loc, *conditions, *statements]
end

#compact_child_nodesObject

def compact_child_nodes: () -> Array



16794
16795
16796
16797
16798
16799
# File 'lib/prism/node.rb', line 16794

def compact_child_nodes
  compact = []
  compact.concat(conditions)
  compact << statements if statements
  compact
end

#copy(**params) ⇒ Object

def copy: (**params) -> WhenNode



16807
16808
16809
16810
16811
16812
16813
16814
# File 'lib/prism/node.rb', line 16807

def copy(**params)
  WhenNode.new(
    params.fetch(:keyword_loc) { keyword_loc },
    params.fetch(:conditions) { conditions },
    params.fetch(:statements) { statements },
    params.fetch(:location) { location },
  )
end

#deconstruct_keys(keys) ⇒ Object

def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array | String | Token | Array | Location]



16820
16821
16822
# File 'lib/prism/node.rb', line 16820

def deconstruct_keys(keys)
  { keyword_loc: keyword_loc, conditions: conditions, statements: statements, location: location }
end

#inspect(inspector = NodeInspector.new) ⇒ Object

def inspect(inspector: NodeInspector) -> String



16830
16831
16832
16833
16834
16835
16836
16837
16838
16839
16840
16841
# File 'lib/prism/node.rb', line 16830

def inspect(inspector = NodeInspector.new)
  inspector << inspector.header(self)
  inspector << "├── keyword_loc: #{inspector.location(keyword_loc)}\n"
  inspector << "├── conditions: #{inspector.list("#{inspector.prefix}", conditions)}"
  if (statements = self.statements).nil?
    inspector << "└── statements: ∅\n"
  else
    inspector << "└── statements:\n"
    inspector << statements.inspect(inspector.child_inspector("    ")).delete_prefix(inspector.prefix)
  end
  inspector.to_str
end

#keywordObject

def keyword: () -> String



16825
16826
16827
# File 'lib/prism/node.rb', line 16825

def keyword
  keyword_loc.slice
end

#typeObject

Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.

Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.

def type: () -> Symbol



16857
16858
16859
# File 'lib/prism/node.rb', line 16857

def type
  :when_node
end