Class: Prism::CallNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::CallNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents a method call, in all of the various forms that can take.
foo
^^^
foo()
^^^^^
+foo
^^^^
foo + bar
^^^^^^^^^
foo.bar
^^^^^^^
foo&.bar
^^^^^^^^
Instance Attribute Summary collapse
-
#arguments ⇒ Object
readonly
attr_reader arguments: ArgumentsNode?.
-
#block ⇒ Object
readonly
attr_reader block: Node?.
-
#call_operator_loc ⇒ Object
readonly
attr_reader call_operator_loc: Location?.
-
#closing_loc ⇒ Object
readonly
attr_reader closing_loc: Location?.
-
#flags ⇒ Object
readonly
Returns the value of attribute flags.
-
#message_loc ⇒ Object
readonly
attr_reader message_loc: Location?.
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
-
#opening_loc ⇒ Object
readonly
attr_reader opening_loc: Location?.
-
#receiver ⇒ Object
readonly
attr_reader receiver: Node?.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#attribute_write? ⇒ Boolean
def attribute_write?: () -> bool.
-
#call_operator ⇒ Object
def call_operator: () -> String?.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#closing ⇒ Object
def closing: () -> String?.
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> CallNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(flags, receiver, call_operator_loc, name, message_loc, opening_loc, arguments, closing_loc, block, location) ⇒ CallNode
constructor
def initialize: (flags: Integer, receiver: Node?, call_operator_loc: Location?, name: Symbol, message_loc: Location?, opening_loc: Location?, arguments: ArgumentsNode?, closing_loc: Location?, block: Node?, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#message ⇒ Object
def message: () -> String?.
-
#opening ⇒ Object
def opening: () -> String?.
-
#safe_navigation? ⇒ Boolean
def safe_navigation?: () -> bool.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
-
#variable_call? ⇒ Boolean
def variable_call?: () -> bool.
Constructor Details
#initialize(flags, receiver, call_operator_loc, name, message_loc, opening_loc, arguments, closing_loc, block, location) ⇒ CallNode
def initialize: (flags: Integer, receiver: Node?, call_operator_loc: Location?, name: Symbol, message_loc: Location?, opening_loc: Location?, arguments: ArgumentsNode?, closing_loc: Location?, block: Node?, location: Location) -> void
2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/prism/node.rb', line 2182 def initialize(flags, receiver, call_operator_loc, name, , opening_loc, arguments, closing_loc, block, location) @flags = flags @receiver = receiver @call_operator_loc = call_operator_loc @name = name @message_loc = @opening_loc = opening_loc @arguments = arguments @closing_loc = closing_loc @block = block @location = location end |
Instance Attribute Details
#arguments ⇒ Object (readonly)
attr_reader arguments: ArgumentsNode?
2173 2174 2175 |
# File 'lib/prism/node.rb', line 2173 def arguments @arguments end |
#block ⇒ Object (readonly)
attr_reader block: Node?
2179 2180 2181 |
# File 'lib/prism/node.rb', line 2179 def block @block end |
#call_operator_loc ⇒ Object (readonly)
attr_reader call_operator_loc: Location?
2161 2162 2163 |
# File 'lib/prism/node.rb', line 2161 def call_operator_loc @call_operator_loc end |
#closing_loc ⇒ Object (readonly)
attr_reader closing_loc: Location?
2176 2177 2178 |
# File 'lib/prism/node.rb', line 2176 def closing_loc @closing_loc end |
#flags ⇒ Object (readonly)
Returns the value of attribute flags.
2155 2156 2157 |
# File 'lib/prism/node.rb', line 2155 def flags @flags end |
#message_loc ⇒ Object (readonly)
attr_reader message_loc: Location?
2167 2168 2169 |
# File 'lib/prism/node.rb', line 2167 def @message_loc end |
#name ⇒ Object (readonly)
attr_reader name: Symbol
2164 2165 2166 |
# File 'lib/prism/node.rb', line 2164 def name @name end |
#opening_loc ⇒ Object (readonly)
attr_reader opening_loc: Location?
2170 2171 2172 |
# File 'lib/prism/node.rb', line 2170 def opening_loc @opening_loc end |
#receiver ⇒ Object (readonly)
attr_reader receiver: Node?
2158 2159 2160 |
# File 'lib/prism/node.rb', line 2158 def receiver @receiver end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
2333 2334 2335 |
# File 'lib/prism/node.rb', line 2333 def self.type :call_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
2196 2197 2198 |
# File 'lib/prism/node.rb', line 2196 def accept(visitor) visitor.visit_call_node(self) end |
#attribute_write? ⇒ Boolean
def attribute_write?: () -> bool
2254 2255 2256 |
# File 'lib/prism/node.rb', line 2254 def attribute_write? flags.anybits?(CallNodeFlags::ATTRIBUTE_WRITE) end |
#call_operator ⇒ Object
def call_operator: () -> String?
2259 2260 2261 |
# File 'lib/prism/node.rb', line 2259 def call_operator call_operator_loc&.slice end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
2201 2202 2203 |
# File 'lib/prism/node.rb', line 2201 def child_nodes [receiver, arguments, block] end |
#closing ⇒ Object
def closing: () -> String?
2274 2275 2276 |
# File 'lib/prism/node.rb', line 2274 def closing closing_loc&.slice end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
2215 2216 2217 |
# File 'lib/prism/node.rb', line 2215 def comment_targets [*receiver, *call_operator_loc, *, *opening_loc, *arguments, *closing_loc, *block] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
2206 2207 2208 2209 2210 2211 2212 |
# File 'lib/prism/node.rb', line 2206 def compact_child_nodes compact = [] compact << receiver if receiver compact << arguments if arguments compact << block if block compact end |
#copy(**params) ⇒ Object
def copy: (**params) -> CallNode
2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 |
# File 'lib/prism/node.rb', line 2220 def copy(**params) CallNode.new( params.fetch(:flags) { flags }, params.fetch(:receiver) { receiver }, params.fetch(:call_operator_loc) { call_operator_loc }, params.fetch(:name) { name }, params.fetch(:message_loc) { }, params.fetch(:opening_loc) { opening_loc }, params.fetch(:arguments) { arguments }, params.fetch(:closing_loc) { closing_loc }, params.fetch(:block) { block }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
2239 2240 2241 |
# File 'lib/prism/node.rb', line 2239 def deconstruct_keys(keys) { flags: flags, receiver: receiver, call_operator_loc: call_operator_loc, name: name, message_loc: , opening_loc: opening_loc, arguments: arguments, closing_loc: closing_loc, block: block, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 |
# File 'lib/prism/node.rb', line 2279 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) flags = [("safe_navigation" if ), ("variable_call" if variable_call?), ("attribute_write" if attribute_write?)].compact inspector << "├── flags: #{flags.empty? ? "∅" : flags.join(", ")}\n" if (receiver = self.receiver).nil? inspector << "├── receiver: ∅\n" else inspector << "├── receiver:\n" inspector << receiver.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── call_operator_loc: #{inspector.location(call_operator_loc)}\n" inspector << "├── name: #{name.inspect}\n" inspector << "├── message_loc: #{inspector.location()}\n" inspector << "├── opening_loc: #{inspector.location(opening_loc)}\n" if (arguments = self.arguments).nil? inspector << "├── arguments: ∅\n" else inspector << "├── arguments:\n" inspector << arguments.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── closing_loc: #{inspector.location(closing_loc)}\n" if (block = self.block).nil? inspector << "└── block: ∅\n" else inspector << "└── block:\n" inspector << block.inspect(inspector.child_inspector(" ")).delete_prefix(inspector.prefix) end inspector.to_str end |
#message ⇒ Object
def message: () -> String?
2264 2265 2266 |
# File 'lib/prism/node.rb', line 2264 def &.slice end |
#opening ⇒ Object
def opening: () -> String?
2269 2270 2271 |
# File 'lib/prism/node.rb', line 2269 def opening opening_loc&.slice end |
#safe_navigation? ⇒ Boolean
def safe_navigation?: () -> bool
2244 2245 2246 |
# File 'lib/prism/node.rb', line 2244 def flags.anybits?(CallNodeFlags::SAFE_NAVIGATION) end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
2323 2324 2325 |
# File 'lib/prism/node.rb', line 2323 def type :call_node end |
#variable_call? ⇒ Boolean
def variable_call?: () -> bool
2249 2250 2251 |
# File 'lib/prism/node.rb', line 2249 def variable_call? flags.anybits?(CallNodeFlags::VARIABLE_CALL) end |