Class: Prism::CallOrWriteNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::CallOrWriteNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents the use of the ‘||=` operator on a call.
foo.bar ||= value
^^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#call_operator_loc ⇒ Object
readonly
attr_reader call_operator_loc: Location?.
-
#flags ⇒ Object
readonly
Returns the value of attribute flags.
-
#message_loc ⇒ Object
readonly
attr_reader message_loc: Location?.
-
#operator_loc ⇒ Object
readonly
attr_reader operator_loc: Location.
-
#read_name ⇒ Object
readonly
attr_reader read_name: Symbol.
-
#receiver ⇒ Object
readonly
attr_reader receiver: Node?.
-
#value ⇒ Object
readonly
attr_reader value: Node.
-
#write_name ⇒ Object
readonly
attr_reader write_name: Symbol.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#attribute_write? ⇒ Boolean
def attribute_write?: () -> bool.
-
#call_operator ⇒ Object
def call_operator: () -> String?.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> CallOrWriteNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(flags, receiver, call_operator_loc, message_loc, read_name, write_name, operator_loc, value, location) ⇒ CallOrWriteNode
constructor
def initialize: (flags: Integer, receiver: Node?, call_operator_loc: Location?, message_loc: Location?, read_name: Symbol, write_name: Symbol, operator_loc: Location, value: Node, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#message ⇒ Object
def message: () -> String?.
-
#operator ⇒ Object
def operator: () -> String.
-
#safe_navigation? ⇒ Boolean
def safe_navigation?: () -> bool.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
-
#variable_call? ⇒ Boolean
def variable_call?: () -> bool.
Constructor Details
#initialize(flags, receiver, call_operator_loc, message_loc, read_name, write_name, operator_loc, value, location) ⇒ CallOrWriteNode
def initialize: (flags: Integer, receiver: Node?, call_operator_loc: Location?, message_loc: Location?, read_name: Symbol, write_name: Symbol, operator_loc: Location, value: Node, location: Location) -> void
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/prism/node.rb', line 2537 def initialize(flags, receiver, call_operator_loc, , read_name, write_name, operator_loc, value, location) @flags = flags @receiver = receiver @call_operator_loc = call_operator_loc @message_loc = @read_name = read_name @write_name = write_name @operator_loc = operator_loc @value = value @location = location end |
Instance Attribute Details
#call_operator_loc ⇒ Object (readonly)
attr_reader call_operator_loc: Location?
2519 2520 2521 |
# File 'lib/prism/node.rb', line 2519 def call_operator_loc @call_operator_loc end |
#flags ⇒ Object (readonly)
Returns the value of attribute flags.
2513 2514 2515 |
# File 'lib/prism/node.rb', line 2513 def flags @flags end |
#message_loc ⇒ Object (readonly)
attr_reader message_loc: Location?
2522 2523 2524 |
# File 'lib/prism/node.rb', line 2522 def @message_loc end |
#operator_loc ⇒ Object (readonly)
attr_reader operator_loc: Location
2531 2532 2533 |
# File 'lib/prism/node.rb', line 2531 def operator_loc @operator_loc end |
#read_name ⇒ Object (readonly)
attr_reader read_name: Symbol
2525 2526 2527 |
# File 'lib/prism/node.rb', line 2525 def read_name @read_name end |
#receiver ⇒ Object (readonly)
attr_reader receiver: Node?
2516 2517 2518 |
# File 'lib/prism/node.rb', line 2516 def receiver @receiver end |
#value ⇒ Object (readonly)
attr_reader value: Node
2534 2535 2536 |
# File 'lib/prism/node.rb', line 2534 def value @value end |
#write_name ⇒ Object (readonly)
attr_reader write_name: Symbol
2528 2529 2530 |
# File 'lib/prism/node.rb', line 2528 def write_name @write_name end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
2670 2671 2672 |
# File 'lib/prism/node.rb', line 2670 def self.type :call_or_write_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
2550 2551 2552 |
# File 'lib/prism/node.rb', line 2550 def accept(visitor) visitor.visit_call_or_write_node(self) end |
#attribute_write? ⇒ Boolean
def attribute_write?: () -> bool
2606 2607 2608 |
# File 'lib/prism/node.rb', line 2606 def attribute_write? flags.anybits?(CallNodeFlags::ATTRIBUTE_WRITE) end |
#call_operator ⇒ Object
def call_operator: () -> String?
2611 2612 2613 |
# File 'lib/prism/node.rb', line 2611 def call_operator call_operator_loc&.slice end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
2555 2556 2557 |
# File 'lib/prism/node.rb', line 2555 def child_nodes [receiver, value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
2568 2569 2570 |
# File 'lib/prism/node.rb', line 2568 def comment_targets [*receiver, *call_operator_loc, *, operator_loc, value] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
2560 2561 2562 2563 2564 2565 |
# File 'lib/prism/node.rb', line 2560 def compact_child_nodes compact = [] compact << receiver if receiver compact << value compact end |
#copy(**params) ⇒ Object
def copy: (**params) -> CallOrWriteNode
2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 |
# File 'lib/prism/node.rb', line 2573 def copy(**params) CallOrWriteNode.new( params.fetch(:flags) { flags }, params.fetch(:receiver) { receiver }, params.fetch(:call_operator_loc) { call_operator_loc }, params.fetch(:message_loc) { }, params.fetch(:read_name) { read_name }, params.fetch(:write_name) { write_name }, params.fetch(:operator_loc) { operator_loc }, params.fetch(:value) { value }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
2591 2592 2593 |
# File 'lib/prism/node.rb', line 2591 def deconstruct_keys(keys) { flags: flags, receiver: receiver, call_operator_loc: call_operator_loc, message_loc: , read_name: read_name, write_name: write_name, operator_loc: operator_loc, value: value, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/prism/node.rb', line 2626 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) flags = [("safe_navigation" if ), ("variable_call" if variable_call?), ("attribute_write" if attribute_write?)].compact inspector << "├── flags: #{flags.empty? ? "∅" : flags.join(", ")}\n" if (receiver = self.receiver).nil? inspector << "├── receiver: ∅\n" else inspector << "├── receiver:\n" inspector << receiver.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── call_operator_loc: #{inspector.location(call_operator_loc)}\n" inspector << "├── message_loc: #{inspector.location()}\n" inspector << "├── read_name: #{read_name.inspect}\n" inspector << "├── write_name: #{write_name.inspect}\n" inspector << "├── operator_loc: #{inspector.location(operator_loc)}\n" inspector << "└── value:\n" inspector << inspector.child_node(value, " ") inspector.to_str end |
#message ⇒ Object
def message: () -> String?
2616 2617 2618 |
# File 'lib/prism/node.rb', line 2616 def &.slice end |
#operator ⇒ Object
def operator: () -> String
2621 2622 2623 |
# File 'lib/prism/node.rb', line 2621 def operator operator_loc.slice end |
#safe_navigation? ⇒ Boolean
def safe_navigation?: () -> bool
2596 2597 2598 |
# File 'lib/prism/node.rb', line 2596 def flags.anybits?(CallNodeFlags::SAFE_NAVIGATION) end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
2660 2661 2662 |
# File 'lib/prism/node.rb', line 2660 def type :call_or_write_node end |
#variable_call? ⇒ Boolean
def variable_call?: () -> bool
2601 2602 2603 |
# File 'lib/prism/node.rb', line 2601 def variable_call? flags.anybits?(CallNodeFlags::VARIABLE_CALL) end |