Class: Prism::ConstantPathNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::ConstantPathNode
- Defined in:
- lib/prism/node.rb,
lib/prism/node_ext.rb,
ext/prism/api_node.c
Overview
Represents accessing a constant through a path of ‘::` operators.
Foo::Bar
^^^^^^^^
Defined Under Namespace
Classes: DynamicPartsInConstantPathError
Instance Attribute Summary collapse
-
#child ⇒ Object
readonly
attr_reader child: Node.
-
#delimiter_loc ⇒ Object
readonly
attr_reader delimiter_loc: Location.
-
#parent ⇒ Object
readonly
attr_reader parent: Node?.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> ConstantPathNode.
- #deconstruct_keys(keys) ⇒ Object
-
#delimiter ⇒ Object
def delimiter: () -> String.
-
#full_name ⇒ Object
Returns the full name of this constant path.
-
#full_name_parts ⇒ Object
Returns the list of parts for the full name of this constant path.
-
#initialize(parent, child, delimiter_loc, location) ⇒ ConstantPathNode
constructor
def initialize: (parent: Node?, child: Node, delimiter_loc: Location, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(parent, child, delimiter_loc, location) ⇒ ConstantPathNode
def initialize: (parent: Node?, child: Node, delimiter_loc: Location, location: Location) -> void
4419 4420 4421 4422 4423 4424 |
# File 'lib/prism/node.rb', line 4419 def initialize(parent, child, delimiter_loc, location) @parent = parent @child = child @delimiter_loc = delimiter_loc @location = location end |
Instance Attribute Details
#child ⇒ Object (readonly)
attr_reader child: Node
4413 4414 4415 |
# File 'lib/prism/node.rb', line 4413 def child @child end |
#delimiter_loc ⇒ Object (readonly)
attr_reader delimiter_loc: Location
4416 4417 4418 |
# File 'lib/prism/node.rb', line 4416 def delimiter_loc @delimiter_loc end |
#parent ⇒ Object (readonly)
attr_reader parent: Node?
4410 4411 4412 |
# File 'lib/prism/node.rb', line 4410 def parent @parent end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
4511 4512 4513 |
# File 'lib/prism/node.rb', line 4511 def self.type :constant_path_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
4427 4428 4429 |
# File 'lib/prism/node.rb', line 4427 def accept(visitor) visitor.visit_constant_path_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
4432 4433 4434 |
# File 'lib/prism/node.rb', line 4432 def child_nodes [parent, child] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
4445 4446 4447 |
# File 'lib/prism/node.rb', line 4445 def comment_targets [*parent, child, delimiter_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
4437 4438 4439 4440 4441 4442 |
# File 'lib/prism/node.rb', line 4437 def compact_child_nodes compact = [] compact << parent if parent compact << child compact end |
#copy(**params) ⇒ Object
def copy: (**params) -> ConstantPathNode
4450 4451 4452 4453 4454 4455 4456 4457 |
# File 'lib/prism/node.rb', line 4450 def copy(**params) ConstantPathNode.new( params.fetch(:parent) { parent }, params.fetch(:child) { child }, params.fetch(:delimiter_loc) { delimiter_loc }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
4463 4464 4465 |
# File 'lib/prism/node.rb', line 4463 def deconstruct_keys(keys) { parent: parent, child: child, delimiter_loc: delimiter_loc, location: location } end |
#delimiter ⇒ Object
def delimiter: () -> String
4468 4469 4470 |
# File 'lib/prism/node.rb', line 4468 def delimiter delimiter_loc.slice end |
#full_name ⇒ Object
Returns the full name of this constant path. For example: “Foo::Bar”
129 130 131 |
# File 'lib/prism/node_ext.rb', line 129 def full_name full_name_parts.join("::") end |
#full_name_parts ⇒ Object
Returns the list of parts for the full name of this constant path. For example: [:Foo, :Bar]
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/prism/node_ext.rb', line 112 def full_name_parts parts = [child.name] current = parent while current.is_a?(ConstantPathNode) parts.unshift(current.child.name) current = current.parent end unless current.is_a?(ConstantReadNode) raise DynamicPartsInConstantPathError, "Constant path contains dynamic parts. Cannot compute full name" end parts.unshift(current&.name || :"") end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 |
# File 'lib/prism/node.rb', line 4473 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) if (parent = self.parent).nil? inspector << "├── parent: ∅\n" else inspector << "├── parent:\n" inspector << parent.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── child:\n" inspector << inspector.child_node(child, "│ ") inspector << "└── delimiter_loc: #{inspector.location(delimiter_loc)}\n" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
4501 4502 4503 |
# File 'lib/prism/node.rb', line 4501 def type :constant_path_node end |