Class: Prism::HashPatternNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::HashPatternNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents a hash pattern in pattern matching.
foo => { a: 1, b: 2 }
^^^^^^^^^^^^^^
foo => { a: 1, b: 2, **c }
^^^^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#closing_loc ⇒ Object
readonly
attr_reader closing_loc: Location?.
-
#constant ⇒ Object
readonly
attr_reader constant: Node?.
-
#elements ⇒ Object
readonly
attr_reader elements: Array.
-
#opening_loc ⇒ Object
readonly
attr_reader opening_loc: Location?.
-
#rest ⇒ Object
readonly
attr_reader rest: Node?.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#closing ⇒ Object
def closing: () -> String?.
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> HashPatternNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(constant, elements, rest, opening_loc, closing_loc, location) ⇒ HashPatternNode
constructor
def initialize: (constant: Node?, elements: Array, rest: Node?, opening_loc: Location?, closing_loc: Location?, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#opening ⇒ Object
def opening: () -> String?.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(constant, elements, rest, opening_loc, closing_loc, location) ⇒ HashPatternNode
def initialize: (constant: Node?, elements: Array, rest: Node?, opening_loc: Location?, closing_loc: Location?, location: Location) -> void
7404 7405 7406 7407 7408 7409 7410 7411 |
# File 'lib/prism/node.rb', line 7404 def initialize(constant, elements, rest, opening_loc, closing_loc, location) @constant = constant @elements = elements @rest = rest @opening_loc = opening_loc @closing_loc = closing_loc @location = location end |
Instance Attribute Details
#closing_loc ⇒ Object (readonly)
attr_reader closing_loc: Location?
7401 7402 7403 |
# File 'lib/prism/node.rb', line 7401 def closing_loc @closing_loc end |
#constant ⇒ Object (readonly)
attr_reader constant: Node?
7389 7390 7391 |
# File 'lib/prism/node.rb', line 7389 def constant @constant end |
#elements ⇒ Object (readonly)
attr_reader elements: Array
7392 7393 7394 |
# File 'lib/prism/node.rb', line 7392 def elements @elements end |
#opening_loc ⇒ Object (readonly)
attr_reader opening_loc: Location?
7398 7399 7400 |
# File 'lib/prism/node.rb', line 7398 def opening_loc @opening_loc end |
#rest ⇒ Object (readonly)
attr_reader rest: Node?
7395 7396 7397 |
# File 'lib/prism/node.rb', line 7395 def rest @rest end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
7512 7513 7514 |
# File 'lib/prism/node.rb', line 7512 def self.type :hash_pattern_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
7414 7415 7416 |
# File 'lib/prism/node.rb', line 7414 def accept(visitor) visitor.visit_hash_pattern_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
7419 7420 7421 |
# File 'lib/prism/node.rb', line 7419 def child_nodes [constant, *elements, rest] end |
#closing ⇒ Object
def closing: () -> String?
7463 7464 7465 |
# File 'lib/prism/node.rb', line 7463 def closing closing_loc&.slice end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
7433 7434 7435 |
# File 'lib/prism/node.rb', line 7433 def comment_targets [*constant, *elements, *rest, *opening_loc, *closing_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
7424 7425 7426 7427 7428 7429 7430 |
# File 'lib/prism/node.rb', line 7424 def compact_child_nodes compact = [] compact << constant if constant compact.concat(elements) compact << rest if rest compact end |
#copy(**params) ⇒ Object
def copy: (**params) -> HashPatternNode
7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 |
# File 'lib/prism/node.rb', line 7438 def copy(**params) HashPatternNode.new( params.fetch(:constant) { constant }, params.fetch(:elements) { elements }, params.fetch(:rest) { rest }, params.fetch(:opening_loc) { opening_loc }, params.fetch(:closing_loc) { closing_loc }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
7453 7454 7455 |
# File 'lib/prism/node.rb', line 7453 def deconstruct_keys(keys) { constant: constant, elements: elements, rest: rest, opening_loc: opening_loc, closing_loc: closing_loc, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/prism/node.rb', line 7468 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) if (constant = self.constant).nil? inspector << "├── constant: ∅\n" else inspector << "├── constant:\n" inspector << constant.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── elements: #{inspector.list("#{inspector.prefix}│ ", elements)}" if (rest = self.rest).nil? inspector << "├── rest: ∅\n" else inspector << "├── rest:\n" inspector << rest.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "├── opening_loc: #{inspector.location(opening_loc)}\n" inspector << "└── closing_loc: #{inspector.location(closing_loc)}\n" inspector.to_str end |
#opening ⇒ Object
def opening: () -> String?
7458 7459 7460 |
# File 'lib/prism/node.rb', line 7458 def opening opening_loc&.slice end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
7502 7503 7504 |
# File 'lib/prism/node.rb', line 7502 def type :hash_pattern_node end |