Class: Prism::LocalVariableWriteNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::LocalVariableWriteNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents writing to a local variable.
foo = 1
^^^^^^^
Instance Attribute Summary collapse
-
#depth ⇒ Object
readonly
attr_reader depth: Integer.
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
-
#name_loc ⇒ Object
readonly
attr_reader name_loc: Location.
-
#operator_loc ⇒ Object
readonly
attr_reader operator_loc: Location.
-
#value ⇒ Object
readonly
attr_reader value: Node.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> LocalVariableWriteNode.
-
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array[Node] | String | Token | Array[Token] | Location].
-
#initialize(name, depth, name_loc, value, operator_loc, location) ⇒ LocalVariableWriteNode
constructor
def initialize: (name: Symbol, depth: Integer, name_loc: Location, value: Node, operator_loc: Location, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#operator ⇒ Object
def operator: () -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(name, depth, name_loc, value, operator_loc, location) ⇒ LocalVariableWriteNode
def initialize: (name: Symbol, depth: Integer, name_loc: Location, value: Node, operator_loc: Location, location: Location) -> void
10805 10806 10807 10808 10809 10810 10811 10812 |
# File 'lib/prism/node.rb', line 10805 def initialize(name, depth, name_loc, value, operator_loc, location) @name = name @depth = depth @name_loc = name_loc @value = value @operator_loc = operator_loc @location = location end |
Instance Attribute Details
#depth ⇒ Object (readonly)
attr_reader depth: Integer
10793 10794 10795 |
# File 'lib/prism/node.rb', line 10793 def depth @depth end |
#name ⇒ Object (readonly)
attr_reader name: Symbol
10790 10791 10792 |
# File 'lib/prism/node.rb', line 10790 def name @name end |
#name_loc ⇒ Object (readonly)
attr_reader name_loc: Location
10796 10797 10798 |
# File 'lib/prism/node.rb', line 10796 def name_loc @name_loc end |
#operator_loc ⇒ Object (readonly)
attr_reader operator_loc: Location
10802 10803 10804 |
# File 'lib/prism/node.rb', line 10802 def operator_loc @operator_loc end |
#value ⇒ Object (readonly)
attr_reader value: Node
10799 10800 10801 |
# File 'lib/prism/node.rb', line 10799 def value @value end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
10895 10896 10897 |
# File 'lib/prism/node.rb', line 10895 def self.type :local_variable_write_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
10815 10816 10817 |
# File 'lib/prism/node.rb', line 10815 def accept(visitor) visitor.visit_local_variable_write_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
10820 10821 10822 |
# File 'lib/prism/node.rb', line 10820 def child_nodes [value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
10830 10831 10832 |
# File 'lib/prism/node.rb', line 10830 def comment_targets [name_loc, value, operator_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
10825 10826 10827 |
# File 'lib/prism/node.rb', line 10825 def compact_child_nodes [value] end |
#copy(**params) ⇒ Object
def copy: (**params) -> LocalVariableWriteNode
10835 10836 10837 10838 10839 10840 10841 10842 10843 10844 |
# File 'lib/prism/node.rb', line 10835 def copy(**params) LocalVariableWriteNode.new( params.fetch(:name) { name }, params.fetch(:depth) { depth }, params.fetch(:name_loc) { name_loc }, params.fetch(:value) { value }, params.fetch(:operator_loc) { operator_loc }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
def deconstruct_keys: (keys: Array) -> Hash[Symbol, nil | Node | Array[Node] | String | Token | Array[Token] | Location]
10850 10851 10852 |
# File 'lib/prism/node.rb', line 10850 def deconstruct_keys(keys) { name: name, depth: depth, name_loc: name_loc, value: value, operator_loc: operator_loc, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 |
# File 'lib/prism/node.rb', line 10860 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── name: #{name.inspect}\n" inspector << "├── depth: #{depth.inspect}\n" inspector << "├── name_loc: #{inspector.location(name_loc)}\n" inspector << "├── value:\n" inspector << inspector.child_node(value, "│ ") inspector << "└── operator_loc: #{inspector.location(operator_loc)}\n" inspector.to_str end |
#operator ⇒ Object
def operator: () -> String
10855 10856 10857 |
# File 'lib/prism/node.rb', line 10855 def operator operator_loc.slice end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of
classes to see what kind of behavior to perform. Usually this is done by
calling [cls1, cls2].include?(node.class) or putting the node into a
case statement and doing case node; when cls1; when cls2; end. Both of
these approaches are relatively slow because of the constant lookups,
method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you're on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
10885 10886 10887 |
# File 'lib/prism/node.rb', line 10885 def type :local_variable_write_node end |