Class: Prism::OptionalKeywordParameterNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::OptionalKeywordParameterNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents an optional keyword parameter to a method, block, or lambda definition.
def a(b: 1)
^^^^
end
Instance Attribute Summary collapse
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
-
#name_loc ⇒ Object
readonly
attr_reader name_loc: Location.
-
#value ⇒ Object
readonly
attr_reader value: Node.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> OptionalKeywordParameterNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(name, name_loc, value, location) ⇒ OptionalKeywordParameterNode
constructor
def initialize: (name: Symbol, name_loc: Location, value: Node, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(name, name_loc, value, location) ⇒ OptionalKeywordParameterNode
def initialize: (name: Symbol, name_loc: Location, value: Node, location: Location) -> void
12859 12860 12861 12862 12863 12864 |
# File 'lib/prism/node.rb', line 12859 def initialize(name, name_loc, value, location) @name = name @name_loc = name_loc @value = value @location = location end |
Instance Attribute Details
#name ⇒ Object (readonly)
attr_reader name: Symbol
12850 12851 12852 |
# File 'lib/prism/node.rb', line 12850 def name @name end |
#name_loc ⇒ Object (readonly)
attr_reader name_loc: Location
12853 12854 12855 |
# File 'lib/prism/node.rb', line 12853 def name_loc @name_loc end |
#value ⇒ Object (readonly)
attr_reader value: Node
12856 12857 12858 |
# File 'lib/prism/node.rb', line 12856 def value @value end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
12938 12939 12940 |
# File 'lib/prism/node.rb', line 12938 def self.type :optional_keyword_parameter_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
12867 12868 12869 |
# File 'lib/prism/node.rb', line 12867 def accept(visitor) visitor.visit_optional_keyword_parameter_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
12872 12873 12874 |
# File 'lib/prism/node.rb', line 12872 def child_nodes [value] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
12882 12883 12884 |
# File 'lib/prism/node.rb', line 12882 def comment_targets [name_loc, value] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
12877 12878 12879 |
# File 'lib/prism/node.rb', line 12877 def compact_child_nodes [value] end |
#copy(**params) ⇒ Object
def copy: (**params) -> OptionalKeywordParameterNode
12887 12888 12889 12890 12891 12892 12893 12894 |
# File 'lib/prism/node.rb', line 12887 def copy(**params) OptionalKeywordParameterNode.new( params.fetch(:name) { name }, params.fetch(:name_loc) { name_loc }, params.fetch(:value) { value }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
12900 12901 12902 |
# File 'lib/prism/node.rb', line 12900 def deconstruct_keys(keys) { name: name, name_loc: name_loc, value: value, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
12905 12906 12907 12908 12909 12910 12911 12912 |
# File 'lib/prism/node.rb', line 12905 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── name: #{name.inspect}\n" inspector << "├── name_loc: #{inspector.location(name_loc)}\n" inspector << "└── value:\n" inspector << inspector.child_node(value, " ") inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
12928 12929 12930 |
# File 'lib/prism/node.rb', line 12928 def type :optional_keyword_parameter_node end |