Class: Prism::RangeNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::RangeNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents the use of the ‘..` or `…` operators.
1..2
^^^^
c if a =~ /left/ ... b =~ /right/
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Instance Attribute Summary collapse
-
#flags ⇒ Object
readonly
Returns the value of attribute flags.
-
#left ⇒ Object
readonly
attr_reader left: Node?.
-
#operator_loc ⇒ Object
readonly
attr_reader operator_loc: Location.
-
#right ⇒ Object
readonly
attr_reader right: Node?.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> RangeNode.
- #deconstruct_keys(keys) ⇒ Object
-
#exclude_end? ⇒ Boolean
def exclude_end?: () -> bool.
-
#initialize(flags, left, right, operator_loc, location) ⇒ RangeNode
constructor
def initialize: (flags: Integer, left: Node?, right: Node?, operator_loc: Location, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#operator ⇒ Object
def operator: () -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(flags, left, right, operator_loc, location) ⇒ RangeNode
def initialize: (flags: Integer, left: Node?, right: Node?, operator_loc: Location, location: Location) -> void
14007 14008 14009 14010 14011 14012 14013 |
# File 'lib/prism/node.rb', line 14007 def initialize(flags, left, right, operator_loc, location) @flags = flags @left = left @right = right @operator_loc = operator_loc @location = location end |
Instance Attribute Details
#flags ⇒ Object (readonly)
Returns the value of attribute flags.
13995 13996 13997 |
# File 'lib/prism/node.rb', line 13995 def flags @flags end |
#left ⇒ Object (readonly)
attr_reader left: Node?
13998 13999 14000 |
# File 'lib/prism/node.rb', line 13998 def left @left end |
#operator_loc ⇒ Object (readonly)
attr_reader operator_loc: Location
14004 14005 14006 |
# File 'lib/prism/node.rb', line 14004 def operator_loc @operator_loc end |
#right ⇒ Object (readonly)
attr_reader right: Node?
14001 14002 14003 |
# File 'lib/prism/node.rb', line 14001 def right @right end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
14112 14113 14114 |
# File 'lib/prism/node.rb', line 14112 def self.type :range_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
14016 14017 14018 |
# File 'lib/prism/node.rb', line 14016 def accept(visitor) visitor.visit_range_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
14021 14022 14023 |
# File 'lib/prism/node.rb', line 14021 def child_nodes [left, right] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
14034 14035 14036 |
# File 'lib/prism/node.rb', line 14034 def comment_targets [*left, *right, operator_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
14026 14027 14028 14029 14030 14031 |
# File 'lib/prism/node.rb', line 14026 def compact_child_nodes compact = [] compact << left if left compact << right if right compact end |
#copy(**params) ⇒ Object
def copy: (**params) -> RangeNode
14039 14040 14041 14042 14043 14044 14045 14046 14047 |
# File 'lib/prism/node.rb', line 14039 def copy(**params) RangeNode.new( params.fetch(:flags) { flags }, params.fetch(:left) { left }, params.fetch(:right) { right }, params.fetch(:operator_loc) { operator_loc }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
14053 14054 14055 |
# File 'lib/prism/node.rb', line 14053 def deconstruct_keys(keys) { flags: flags, left: left, right: right, operator_loc: operator_loc, location: location } end |
#exclude_end? ⇒ Boolean
def exclude_end?: () -> bool
14058 14059 14060 |
# File 'lib/prism/node.rb', line 14058 def exclude_end? flags.anybits?(RangeFlags::EXCLUDE_END) end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
14068 14069 14070 14071 14072 14073 14074 14075 14076 14077 14078 14079 14080 14081 14082 14083 14084 14085 14086 |
# File 'lib/prism/node.rb', line 14068 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) flags = [("exclude_end" if exclude_end?)].compact inspector << "├── flags: #{flags.empty? ? "∅" : flags.join(", ")}\n" if (left = self.left).nil? inspector << "├── left: ∅\n" else inspector << "├── left:\n" inspector << left.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end if (right = self.right).nil? inspector << "├── right: ∅\n" else inspector << "├── right:\n" inspector << right.inspect(inspector.child_inspector("│ ")).delete_prefix(inspector.prefix) end inspector << "└── operator_loc: #{inspector.location(operator_loc)}\n" inspector.to_str end |
#operator ⇒ Object
def operator: () -> String
14063 14064 14065 |
# File 'lib/prism/node.rb', line 14063 def operator operator_loc.slice end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
14102 14103 14104 |
# File 'lib/prism/node.rb', line 14102 def type :range_node end |