Class: Prism::RequiredKeywordParameterNode
- Inherits:
-
PrismNode
- Object
- PrismNode
- Prism::RequiredKeywordParameterNode
- Defined in:
- lib/prism/node.rb,
ext/prism/api_node.c
Overview
Represents a required keyword parameter to a method, block, or lambda definition.
def a(b: )
^^
end
Instance Attribute Summary collapse
-
#name ⇒ Object
readonly
attr_reader name: Symbol.
-
#name_loc ⇒ Object
readonly
attr_reader name_loc: Location.
Class Method Summary collapse
-
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain.
Instance Method Summary collapse
-
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void.
-
#child_nodes ⇒ Object
(also: #deconstruct)
def child_nodes: () -> Array[nil | Node].
-
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location].
-
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array.
-
#copy(**params) ⇒ Object
def copy: (**params) -> RequiredKeywordParameterNode.
- #deconstruct_keys(keys) ⇒ Object
-
#initialize(name, name_loc, location) ⇒ RequiredKeywordParameterNode
constructor
def initialize: (name: Symbol, name_loc: Location, location: Location) -> void.
-
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String.
-
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform.
Constructor Details
#initialize(name, name_loc, location) ⇒ RequiredKeywordParameterNode
def initialize: (name: Symbol, name_loc: Location, location: Location) -> void
14478 14479 14480 14481 14482 |
# File 'lib/prism/node.rb', line 14478 def initialize(name, name_loc, location) @name = name @name_loc = name_loc @location = location end |
Instance Attribute Details
#name ⇒ Object (readonly)
attr_reader name: Symbol
14472 14473 14474 |
# File 'lib/prism/node.rb', line 14472 def name @name end |
#name_loc ⇒ Object (readonly)
attr_reader name_loc: Location
14475 14476 14477 |
# File 'lib/prism/node.rb', line 14475 def name_loc @name_loc end |
Class Method Details
.type ⇒ Object
Similar to #type, this method returns a symbol that you can use for splitting on the type of the node without having to do a long === chain. Note that like #type, it will still be slower than using == for a single class, but should be faster in a case statement or an array comparison.
def self.type: () -> Symbol
14553 14554 14555 |
# File 'lib/prism/node.rb', line 14553 def self.type :required_keyword_parameter_node end |
Instance Method Details
#accept(visitor) ⇒ Object
def accept: (visitor: Visitor) -> void
14485 14486 14487 |
# File 'lib/prism/node.rb', line 14485 def accept(visitor) visitor.visit_required_keyword_parameter_node(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
def child_nodes: () -> Array[nil | Node]
14490 14491 14492 |
# File 'lib/prism/node.rb', line 14490 def child_nodes [] end |
#comment_targets ⇒ Object
def comment_targets: () -> Array[Node | Location]
14500 14501 14502 |
# File 'lib/prism/node.rb', line 14500 def comment_targets [name_loc] end |
#compact_child_nodes ⇒ Object
def compact_child_nodes: () -> Array
14495 14496 14497 |
# File 'lib/prism/node.rb', line 14495 def compact_child_nodes [] end |
#copy(**params) ⇒ Object
def copy: (**params) -> RequiredKeywordParameterNode
14505 14506 14507 14508 14509 14510 14511 |
# File 'lib/prism/node.rb', line 14505 def copy(**params) RequiredKeywordParameterNode.new( params.fetch(:name) { name }, params.fetch(:name_loc) { name_loc }, params.fetch(:location) { location }, ) end |
#deconstruct_keys(keys) ⇒ Object
14517 14518 14519 |
# File 'lib/prism/node.rb', line 14517 def deconstruct_keys(keys) { name: name, name_loc: name_loc, location: location } end |
#inspect(inspector = NodeInspector.new) ⇒ Object
def inspect(inspector: NodeInspector) -> String
14522 14523 14524 14525 14526 14527 |
# File 'lib/prism/node.rb', line 14522 def inspect(inspector = NodeInspector.new) inspector << inspector.header(self) inspector << "├── name: #{name.inspect}\n" inspector << "└── name_loc: #{inspector.location(name_loc)}\n" inspector.to_str end |
#type ⇒ Object
Sometimes you want to check an instance of a node against a list of classes to see what kind of behavior to perform. Usually this is done by calling ‘[cls1, cls2].include?(node.class)` or putting the node into a case statement and doing `case node; when cls1; when cls2; end`. Both of these approaches are relatively slow because of the constant lookups, method calls, and/or array allocations.
Instead, you can call #type, which will return to you a symbol that you can use for comparison. This is faster than the other approaches because it uses a single integer comparison, but also because if you’re on CRuby you can take advantage of the fact that case statements with all symbol keys will use a jump table.
def type: () -> Symbol
14543 14544 14545 |
# File 'lib/prism/node.rb', line 14543 def type :required_keyword_parameter_node end |